
setwd("~/Documents/marcelo")

rm(list=ls())

####  Brazil's new data does not contain reasons for changing regimens.  Therefore, I will use new data for all sites except Brazil.  
####  I need to read in the old data for Brazil.
d<-read.csv("adultdata-2015-01-01/art.csv")
d1<-read.csv("data-frozen-marcelo-2013-12-20/art.csv")

####  Putting patients into specific regimen classes
d$class<-with(d,ifelse(art_class!="HAART","nonHAART",
                ifelse(t20>0|ccr5>0|ii1>0|ii2>0,"Other",
                ifelse(nnrti>0&pi==0,"NNRTI",
                ifelse(pi>0&nnrti==0&rtv_drug=="Yes","Boosted PI",
                ifelse(pi>0&nnrti==0&rtv_drug=="No","PI",
                ifelse(pi>0&nnrti>0,"Other",
                ifelse(pi==0&nnrti==0&nrti>=3,"3 NRTI","Weirdo"))))))))

d.no.brazil<-d[d$site!="brazil",]
d.no.brazil1<-with(d.no.brazil, data.frame(art_id, site, regimen_class=class, art_sd, art_ed, art_sd_a, art_ed_a, art_rs_oth, art_rs, patient))

d1.brazil<-d1[d1$site=="brazil",]
d1.brazil$site.id<-with(d1.brazil, paste("br",patient,sep="."))
d1.brazil$patient<-d1.brazil$site.id
d1.brazil$site.id<-NULL

d<-rbind(d.no.brazil1, d1.brazil)
d$art_sd<-as.Date(d$art_sd)
d<-d[order(d$patient,d$art_sd),]           

d$art<-as.character(d$art_id)

#class<-ifelse(d$regimen_class=="unboosted PI","PI",as.character(d$regimen_class))

d$start.date1<-as.Date(d$art_sd)
d$stop.date1<-as.Date(d$art_ed)
d$reason<-d$art_rs
d$reason.oth<-d$art_rs_oth

unique.id<-unique(d$patient)

####  Much faster than what was previously used
dup1<-duplicated(data.frame(patient=d$patient))
dup2<-duplicated(data.frame(patient=d$patient,dup1))
dup3<-duplicated(data.frame(patient=d$patient,dup1,dup2))

locate1<-which(dup1==FALSE&dup2==FALSE&dup3==FALSE)
locate2<-which(dup1==TRUE&dup2==FALSE&dup3==FALSE)
locate3<-which(dup1==TRUE&dup2==TRUE&dup3==FALSE)

id1<-data.frame(id=d$patient[locate1],locate1)
id2<-data.frame(id=d$patient[locate2],locate2)
id3<-data.frame(id=d$patient[locate3],locate3)

id2a<-merge(id1,id2,all.x=TRUE)
id3a<-merge(id1,id3,all.x=TRUE)

locate2<-id2a$locate2
locate3<-id3a$locate3

# 
# locate1<-locate2<-locate3<-rep(NA,length(unique.id))
# for (i in 1:length(unique.id)) {
#   if (length(unique(start.date[id.site==unique.id[i]&!is.na(start.date)])) >=1) {
#     locate1[i]<-which(id.site==unique.id[i]&
#                       start.date==min(start.date[id.site==unique.id[i]],na.rm=TRUE))
#     if (length(unique(start.date[id.site==unique.id[i]&!is.na(start.date)])) >1) {
#       locate2[i]<-which(id.site==unique.id[i]&
#                         start.date==min(start.date[id.site==unique.id[i]&
#                                                    start.date!=min(start.date[id.site==unique.id[i]],
#                                                                    na.rm=TRUE)
#                                                    ],na.rm=TRUE))
#       if (length(unique(start.date[id.site==unique.id[i]&!is.na(start.date)])) >2) {
#         locate3[i]<-which(id.site==unique.id[i]&
#                           start.date==min(start.date[id.site==unique.id[i]&
#                                                      start.date!=min(start.date[id.site==unique.id[i]],
#                                                                      na.rm=TRUE) &
#                                                      start.date!=min(start.date[id.site==unique.id[i]&
#                                                                                 start.date!=min(start.date[id.site==unique.id[i]],na.rm=TRUE)],
#                                                                      na.rm=TRUE)
#                                                      ],na.rm=TRUE))
#       }
#     }
#   }
# }



######  We need to get start.date for many regimens

#reason.oth<-rep("",length(reason))
d$reas<-with(d, ifelse(reason.oth!="",paste(reason,reason.oth,sep="; "),as.character(reason)))
d$reas<-as.character(d$reas)


#### If missing, then that means they didn't stop (sometimes)

d$reas<-with(d, as.character(ifelse(is.na(reas),"",reas)))

classify.reasons<-function(reason) {
  reason.change<-ifelse(reason=="Abnormal fat redistribution"|
                        reason=="Dyslipidemia"|
                        reason=="Hematological toxicity (anemia etc)"|
                        reason=="Hyperlactataemia/lactic acidosis"|
                        reason=="Hypersensitivity reaction,HSR to abacavir"|
                        reason=="Other causes, not specified above; longterm toxicity"|
                        reason=="Other causes, not specified above; shortterm toxicity"|
                        reason=="Side effects, Any of the above, but unspecified"|
                        reason=="Toxicity Dermatologic"|
                        reason=="Toxicity GI tract"|
                        reason=="Toxicity Liver"|
                        reason=="Toxicity Liver(ALT/Hepatitis)"|
                        reason=="Toxicity, not mentioned above"|
                        reason=="Toxicity Pancreas"|
                        reason=="Toxicity Peripheral neuropathy"|
                        reason=="Toxicity Predominantly from abdomen/GI tract"|
                        reason=="Toxicity Predominantly from endocrine system"|
                        reason=="Toxicity Predominantly from kidneys"|
                        reason=="Toxicity Predominantly from nervous system"|
                        reason=="Toxicity Central nervous system"|
                        reason=="Hypersensitivity"|
                        reason=="Toxicity not mentioned above"|
                        reason=="Side effects Any of the above but unspecified", "toxicity",
                 ifelse(reason=="Treatment failure"|
                        reason=="Virological failure"|
                        reason=="Virologic failure"|
                        reason=="Clinical progression"|
                        reason=="Immunological failure", "failure",
                 ifelse(reason=="Unknown", "unknown",
                 ifelse(reason==""|is.na(reason),"missing","other"))))
  reason.change
}
  

d$reason.cat<-classify.reasons(d$reason)
d$reason.cat<-with(d, ifelse(reason.cat=="missing","unknown",as.character(reason.cat)))  ## Assigning all missing to unknown

unique.reas<-with(d, unique(reason))
cat.unique.reas<-classify.reasons(unique.reas)

counts.unique.reas<-NULL
for (i in 1:length(unique.reas)) {
  counts.unique.reas[i]<-sum(d$reas==unique.reas[i])
}
unique.reasons<-data.frame(reasons=unique.reas,count=counts.unique.reas,category=cat.unique.reas)





classify.reasons2<-function(reason) {
  reason.change<-ifelse(reason=="Toxicity GI tract"|
                        reason=="Toxicity Predominantly from abdomen/GI tract"|
                        reason=="Toxicity Pancreas","Toxicity Gastrointestinal",
                 ifelse(reason=="Hyperlactataemia/lactic acidosis"|
                        reason=="Hypersensitivity"|
                        reason=="Toxicity Predominantly from endocrine system"|
                        reason=="Toxicity, not mentioned above"|
                        reason=="Toxicity not mentioned above","Toxicity Other",
                 ifelse(reason=="Side effects, Any of the above, but unspecified"|
                        reason=="Side effects Any of the above but unspecified","Toxicity Unspecified",
                 ifelse(reason=="Availabilty of more effective treatment"|
                        reason=="Change in eligibility criteria"|
                        reason=="Simplified treatment available"|
                        reason=="Protocol change"|
                        reason=="Preferred drug now available","Regimen Improvement",
                 ifelse(reason=="Comorbidity"|
                        reason=="Comorbidity resolved"|
                        reason=="Concern of cardiovascular disease"|
                        reason=="Cardiovascular disease"|
                        reason=="Drug interaction"|
                        reason=="Drug interaction, commencing TB treatment"|
                        reason=="Drug interaction commencing TB treatment"|
                        reason=="Drug interaction, ended TB treatment"|
                        reason=="Drug interaction ended TB treatment"|
                        reason=="Diabetes","Comorbidities/Drug Interaction",
                 ifelse(reason=="Non-adherence"|
                        reason=="Lost to follow-up"|
                        reason=="Patients wish/decision, not specified above"|
                        reason=="Transfer to another center","Abandonment/Non-adherence",
                 ifelse(reason=="Pregnancy"|
                        reason=="Pregnancy ended"|
                        reason=="Pregnancy intended or possible"|
                        reason=="Preconceptual concerns counseling","Pregnancy Related",
                 ifelse(reason=="Other causes, not specified above"|
                        reason=="Added new drug"|
                        reason=="Drug resistance based on HIV-1 genotype"|
                        reason=="Physicians decision, not specified above"|
                        reason=="Physicians decision not specified above"|
                        reason=="Change in treatment not due to side-effects", "Other reason, not specified above",
                 ifelse(reason=="Structured Treatment Interruption(STI) at high CD4","Structured Treatment Interruption (STI)",
                 ifelse(reason=="", "Unknown",
                        as.character(reason)))))))))))
  reason.change
}


d$reason.cat2<-classify.reasons2(d$reason)

with(d, table(reason.cat2,reason.cat))


######  This requires the regimen dates to be in order;  
# #####   This is considering first change due to failure after starting 2nd regimen -- it may not be while still on second regimen
# 
# locate3.fail<-rep(NA,length(unique.id))
# for (i in 1:length(unique.id)) {
#   if (length(unique(start.date[id.site==unique.id[i]&!is.na(start.date)])) >2 &
#       sum(reason.cat[id.site==unique.id[i]&!is.na(start.date)][-1]=="failure")>0) {
#     locate3.fail[i]<-which(id.site==unique.id[i]&
#                            start.date==min(start.date[id.site==unique.id[i]&reason.cat=="failure"&
#                                                       start.date!=min(start.date[id.site==unique.id[i]],na.rm=TRUE)], 
#                                            na.rm=TRUE))
#   }
# }

#####  Now I'm only considering failure during the 2nd regimen

locate3.fail<-with(d, ifelse(reason.cat[locate2]=="failure",locate2,NA))
locate3.vir.fail<-with(d, ifelse(reas[locate2]=="Virological failure",locate2,NA))
locate3.tox<-with(d, ifelse(reason.cat[locate2]=="toxicity",locate2,NA))

# locate3.fail<-rep(NA,length(unique.id))
# for (i in 1:length(unique.id)) {
#   if (length(unique(stop.date[id.site==unique.id[i]&!is.na(stop.date)])) >=2 & 
#       reason.cat[id.site==unique.id[i]&!is.na(stop.date)][2]=="failure") {
#     locate3.fail[i]<-which(id.site==unique.id[i]&stop.date==stop.date[id.site==unique.id[i]&!is.na(stop.date)][2])
#   }
# }
# 
# #####  Now I'm considering virological failure during the 2nd regimen
# locate3.vir.fail<-rep(NA,length(unique.id))
# for (i in 1:length(unique.id)) {
#   if (length(unique(stop.date[id.site==unique.id[i]&!is.na(stop.date)])) >=2 & 
#       reas[id.site==unique.id[i]&!is.na(stop.date)][2]=="Virological failure") {
#     locate3.vir.fail[i]<-which(id.site==unique.id[i]&stop.date==stop.date[id.site==unique.id[i]&!is.na(stop.date)][2])
#   }
# }
# 
# 
# #####  Time of toxicity change during the 2nd regimen
# locate3.tox<-rep(NA,length(unique.id))
# for (i in 1:length(unique.id)) {
#   if (length(unique(stop.date[id.site==unique.id[i]&!is.na(stop.date)])) >=2 &
#       reason.cat[id.site==unique.id[i]&!is.na(stop.date)][2]=="toxicity") {
#     locate3.tox[i]<-which(id.site==unique.id[i]&stop.date==stop.date[id.site==unique.id[i]&!is.na(stop.date)][2])
#   }
# }




pid<-with(d,patient[locate1])
psite<-with(d,site[locate1])
init.reg<-with(d,art[locate1])
init.class<-with(d,regimen_class[locate1])
init.start.date<-with(d,start.date1[locate1])
init.stop.date<-with(d,stop.date1[locate1])
init.reason<-with(d,reason[locate1])
init.reason.oth<-with(d,reason.oth[locate1])
init.reason.cat<-with(d,reason.cat[locate1])
init.reason.cat2<-with(d,reason.cat2[locate1])
init.reas<-with(d,reas[locate1])


second.reg<-with(d,art[locate2])
second.class<-with(d,regimen_class[locate2])
second.start.date<-with(d,start.date1[locate2])
second.stop.date<-with(d,stop.date1[locate2])
second.reason<-with(d,reason[locate2])
second.reason.oth<-with(d,reason.oth[locate2])
second.reason.cat<-with(d,reason.cat[locate2])
second.reason.cat2<-with(d,reason.cat2[locate2])
second.reas<-with(d,reas[locate2])
second.reason<-with(d,reason[locate2])
second.reason.oth<-with(d,reason.oth[locate2])
second.reason.cat<-with(d,reason.cat[locate2])
second.reas<-with(d,reas[locate2])

third.reg<-with(d,art[locate3])
third.class<-with(d,regimen_class[locate3])
third.start.date<-with(d,start.date1[locate3])
third.stop.date<-with(d,stop.date1[locate3])
third.reason<-with(d,reason[locate3])
third.reason.oth<-with(d,reason.oth[locate3])
third.reason.cat<-with(d,reason.cat[locate3])
third.reason.cat2<-with(d,reason.cat2[locate3])
third.reas<-with(d,reas[locate3])


date.regimen2.change.fail<-with(d,stop.date1[locate3.fail])
date.regimen2.change.vir.fail<-with(d,stop.date1[locate3.vir.fail])
date.regimen2.change.tox<-with(d,stop.date1[locate3.tox])

unique.id.art<-data.frame(id=pid,site=psite,
						  init.reg,init.class,init.start.date,init.stop.date,init.reason,init.reason.oth,init.reason.cat,init.reason.cat2,init.reas,
						second.reg,second.class,second.start.date,second.stop.date,second.reason,second.reason.oth,
						second.reason.cat,second.reason.cat2,second.reas,
                          third.reg,third.class,third.start.date,third.stop.date,third.reason,third.reason.oth,
                          third.reason.cat,third.reason.cat2,third.reas,
                          date.regimen2.change.fail,date.regimen2.change.vir.fail,date.regimen2.change.tox)



d.basic<-read.csv("adultdata-2015-01-01/basic.csv")
d1.basic<-read.csv("data-frozen-marcelo-2013-12-20/basic.csv")

d.basic.no.brazil<-d.basic[d.basic$site!="brazil",]
d1.basic.brazil<-d1.basic[d1.basic$site=="brazil",]
d1.basic.brazil$site.id<-with(d1.basic.brazil, paste("br",patient,sep="."))
d1.basic.brazil$patient<-d1.basic.brazil$site.id
d1.basic.brazil$site.id<-NULL

d1.basic.brazil1<-with(d1.basic.brazil, data.frame(site, patient, birth_d, hivdiagnosis_d, aids_d, mode, mode_oth, birth_d_a, hivdiagnosis_d_a,
                                                   aids_y, clinicaltrial_y, male, recart_y, aids_d_a, cdcstage, whostage, enrol_d, firstvis_d, 
                                                   recart_d, recart_d_a, enrol_d_a, firstvis_d_a, aids_cl_y=NA, aids_cl_d_a=NA, baseline_d=NA))
d.basic.no.brazil1<-with(d.basic.no.brazil, data.frame(site, patient, birth_d, hivdiagnosis_d, aids_d, mode, mode_oth, birth_d_a, hivdiagnosis_d_a,
                                                   aids_y, clinicaltrial_y, male, recart_y, aids_d_a, cdcstage=NA, whostage=NA, enrol_d=NA, firstvis_d=NA, 
                                                   recart_d=NA, recart_d_a=NA, enrol_d_a=NA, firstvis_d_a=NA, aids_cl_y, aids_cl_d_a, baseline_d))

d.basic<-rbind(d.basic.no.brazil1, d1.basic.brazil1)
d.basic<-d.basic[order(d.basic$patient),]


d1<-merge(unique.id.art,d.basic,by.x=c("id","site"),by.y=c("patient","site"),all.x=TRUE)


names(d1)
table(d1$recart_y,d1$site)

d1$age<-with(d1,floor( (as.numeric(as.Date(init.start.date)) -as.numeric(as.Date(birth_d)) )/365.25))


clin.trial<-function(a){
  stuff<-ifelse(a=="MRV/PBO"|a=="RAL/PBO"|a=="EFV/PBO",1,0)
  stuff
}
d1$init.clin.trial<-sapply(lapply(lapply(strsplit(as.character(d1$init.reg),','),clin.trial),sum),FUN=as.numeric)
d1$second.clin.trial<-sapply(lapply(lapply(strsplit(as.character(d1$second.reg),','),clin.trial),sum),FUN=as.numeric)

d1$birth_d_a<-with(d1,ifelse(is.na(birth_d_a),"",as.character(birth_d_a)))
exclude.unknown.age<-ifelse(d1$birth_d=="1900-01-01"|d1$birth_d_a=="U",1,0)
exclude.age<-ifelse(d1$age<18,1,0)
exclude.recart<-ifelse(d1$recart_y!=0,1,0)
exclude.nonHAART.reg1<-ifelse(d1$init.class=="nonHAART",1,0)
exclude.no.reg2<-ifelse(is.na(d1$second.reg),1,0)
exclude.reg2.is.reg1<-ifelse(as.character(d1$init.reg)==as.character(d1$second.reg),1,0)
exclude.nonHAART.reg2<-ifelse(d1$second.class=="nonHAART",1,0)
exclude.clin.trial<-ifelse(d1$init.clin.trial>0|d1$second.clin.trial>0|d1$clinicaltrial_y>0,1,0)
exclude.clin.trial<-ifelse(is.na(exclude.clin.trial),0,exclude.clin.trial)

exclude<-ifelse(exclude.unknown.age==1|exclude.age==1|exclude.recart==1|exclude.nonHAART.reg1==1|
                exclude.no.reg2==1|exclude.reg2.is.reg1==1|exclude.nonHAART.reg2==1|exclude.clin.trial==1,1,0)

exclude.code1<-ifelse(exclude.unknown.age==1,"Age unknown",
               ifelse(exclude.age==1,"Age < 18",
               ifelse(exclude.recart==1,"Not known to be ART naive at enrollment",
               ifelse(exclude.nonHAART.reg1==1,"First Regimen not HAART",
               ifelse(exclude.clin.trial==1,"Part of Clinical Trial",
               ifelse(exclude.no.reg2==1,"No Second Regimen",
               ifelse(exclude.reg2.is.reg1==1,"Second Regimen same as First",
               ifelse(exclude.nonHAART.reg2==1,"Second Regimen not HAART","Included"))))))))
exclude.code<-factor(exclude.code1, levels=c("Age unknown","Age < 18","Not known to be ART naive at enrollment",
                                             "First Regimen not HAART","Part of Clinical Trial","No Second Regimen", 
                                             "Second Regimen not HAART","Second Regimen same as First","Included"),ordered=TRUE)





table.exclude<-table(exclude,as.character(d1$site))
table.exclude.reason<-table(exclude.code,as.character(d1$site))
table.exclude.reason

included<-d1[exclude==0,]

# sum(table.exclude.reason[6:9,])+(1581-445)    ####  The number of HAART-naive adults not on a clinical trial;  
#                                               ####  I've hard coded some numbers given to me by Chile (7/16/2013) 

sum(table.exclude.reason[6:9,])
sum(table.exclude.reason[9,])/sum(table.exclude.reason[6:9,])

table.exclude.reason[9,1]/sum(table.exclude.reason[6:9,1])
table.exclude.reason[9,2]/sum(table.exclude.reason[6:9,2])
table.exclude.reason[9,3]/sum(table.exclude.reason[6:9,3])
table.exclude.reason[9,4]/sum(table.exclude.reason[6:9,4])
table.exclude.reason[9,5]/sum(table.exclude.reason[6:9,5])
table.exclude.reason[9,6]/sum(table.exclude.reason[6:9,6])
table.exclude.reason[9,7]/sum(table.exclude.reason[6:9,7])


included$init.class<-toupper(included$init.class)
included$second.class<-toupper(included$second.class)
included$third.class<-toupper(included$third.class)

save(included,table.exclude,table.exclude.reason,file="included-art.rda")
 
