

rm(list=ls())

setwd("~/Documents/marcelo")
load("d-second-chunk.Rda")

library(survival)
library(rms)
library(mvtnorm)
library(mi)


d<-within(d,{
  init.reason.cat<-factor(init.reason.cat,levels=c("toxicity","failure","other","unknown"))
  site<-as.factor(site)
})



d<-d[which(d$time>0),]

#### Univariate analyses

d$male<-as.numeric(d$male)

time<-d$time
death1<-d$death1
site<-d$site
male<-d$male
age2<-d$age2
cd41<-d$nadir.cd4.prehaart
cd42<-d$cd4.reg2
year2<-d$year.second
time.since.haart.y<-d$time.since.haart/365.25
init.reason.cat<-d$init.reason.cat
n.change<-d$n.change
num.change.cat<-factor(d$num.change.cat,levels=c("Single Drug Substitution","Multidrug Change","Single Drug Addition/Deletion"))
classify.type.arv.change<-d$classify.type.arv.change
classify.type.arv.change.m<-d$classify.type.arv.change.m
change2<-d$change2
time.change2<-d$time.change2
aids.enrollment<-ifelse(d$aids.enrollment=="Unknown",NA,ifelse(d$aids.enrollment=="AIDS",1,0))
change2.tox<-d$change2.tox
change2.fail<-d$change2.fail
change2.vir.fail<-d$change2.vir.fail
time.change2.tox<-d$time.change2.tox
time.change2.fail<-d$time.change2.fail
time.change2.vir.fail<-d$time.change2.vir.fail
delta.cd4<-d$cd4.reg2-d$nadir.cd4.prehaart

dd<-datadist(time,death1,site,male,age2,cd41,cd42,year2,time.since.haart.y,init.reason.cat,num.change.cat,
             classify.type.arv.change,classify.type.arv.change.m,aids.enrollment,delta.cd4)
options(datadist="dd")

mod.male.death<-coxph(Surv(time,death1)~male+strata(site))
mod.age.death<-cph(Surv(time,death1)~rcs(age2,4)+strat(site))
mod.aids.death<-coxph(Surv(time,death1)~aids.enrollment+strata(site))
mod.cd41.death<-cph(Surv(time,death1)~rcs(sqrt(cd41),4)+strat(site))
mod.cd42.death<-cph(Surv(time,death1)~rcs(sqrt(cd42),4)+strat(site))
mod.delta.cd4.death<-cph(Surv(time,death1)~rcs(delta.cd4,4)+strat(site))
mod.year2.death<-coxph(Surv(time,death1)~year2+strata(site))   #removed non-linear piece
mod.lengthart1.death<-cph(Surv(time,death1)~rcs(log(time.since.haart.y),3)+strat(site))
mod.initreas.death<-coxph(Surv(time,death1)~init.reason.cat+strata(site))
mod.ndrugs.death<-coxph(Surv(time,death1)~n.change+strata(site))
mod.ndrugscat.death<-coxph(Surv(time,death1)~num.change.cat+strata(site))
mod.typechange.death<-coxph(Surv(time,death1)~classify.type.arv.change+strata(site))
mod.typechange.m.death<-coxph(Surv(time,death1)~classify.type.arv.change.m+strata(site))


# #options(contrasts=c("contr.treatment","contr.treatment"))
# 
# a<-classify.type.arv.change.m
# b<-ifelse(a=="Change of NRTI","nrti",
#           ifelse(a=="Change of NNRTI","nnrti",
#                  ifelse(a=="Change of NRTI and NNRTI","nrti.nnrti",
#                         ifelse(a=="Change of PI","pi",
#                                ifelse(a=="Change of NRTI and PI","nrti.pi",
#                                       ifelse(a=="Other","other","unknown"))))))
# c<-factor(b,levels=c("nrti","nnrti","nrti.nnrti","pi","nrti.pi","other"),order=TRUE)
# 
# 
# modc<-coxph(Surv(time,death1)~c+strata(site))
# modb<-coxph(Surv(time,death1)~b+strata(site))


hr.male.d<-summary(mod.male.death)$conf.int[c(1,3,4)]
p.male.d<-summary(mod.male.death)$logtest[3]

p.age.d<-anova(mod.age.death)[3,3]
hr.age.d<-rbind(summary(mod.age.death,age2=c(40,20))[2,c(4,6,7)],
                summary(mod.age.death,age2=c(40,30))[2,c(4,6,7)],
                summary(mod.age.death,age2=c(40,50))[2,c(4,6,7)])

hr.aids.d<-summary(mod.aids.death)$conf.int[c(1,3,4)]
p.aids.d<-summary(mod.aids.death)$logtest[3]

p.cd41.d<-anova(mod.cd41.death)[3,3]
hr.cd41.d<-rbind(summary(mod.cd41.death,cd41=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd41.death,cd41=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd41.death,cd41=c(350,200))[2,c(4,6,7)])

p.cd42.d<-anova(mod.cd42.death)[3,3]
hr.cd42.d<-rbind(summary(mod.cd42.death,cd42=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd42.death,cd42=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd42.death,cd42=c(350,200))[2,c(4,6,7)])

p.delta.cd4.d<-anova(mod.delta.cd4.death)[3,3]
hr.delta.cd4.d<-rbind(summary(mod.delta.cd4.death,delta.cd4=c(0,-50))[2,c(4,6,7)],
                 summary(mod.delta.cd4.death,delta.cd4=c(0,50))[2,c(4,6,7)],
                 summary(mod.delta.cd4.death,delta.cd4=c(0,100))[2,c(4,6,7)],
                 summary(mod.delta.cd4.death,delta.cd4=c(0,200))[2,c(4,6,7)],
                 summary(mod.delta.cd4.death,delta.cd4=c(0,300))[2,c(4,6,7)])

hr.year2.d<-summary(mod.year2.death)$conf.int[c(1,3,4)]
p.year2.d<-summary(mod.year2.death)$logtest[3]

p.lengthart1.d<-anova(mod.lengthart1.death)[3,3]
hr.lengthart1.d<-rbind(summary(mod.lengthart1.death,time.since.haart.y=c(3/12,6/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.death,time.since.haart.y=c(3/12,12/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.death,time.since.haart.y=c(3/12,2))[2,c(4,6,7)],
                       summary(mod.lengthart1.death,time.since.haart.y=c(3/12,3))[2,c(4,6,7)])

hr.initreas.d<-summary(mod.initreas.death)$conf.int[,c(1,3,4)]
p.initreas.d<-c(summary(mod.initreas.death)$logtest[3],
                summary(mod.initreas.death)$coeff[,5])

hr.ndrugs.d<-summary(mod.ndrugs.death)$conf.int[c(1,3,4)]
p.ndrugs.d<-summary(mod.ndrugs.death)$logtest[3]

hr.ndrugscat.d<-summary(mod.ndrugscat.death)$conf.int[,c(1,3,4)]
p.ndrugscat.d<-c(summary(mod.ndrugscat.death)$logtest[3],
                 summary(mod.ndrugscat.death)$coeff[,5])
 
hr.typechange.d<-summary(mod.typechange.death)$conf.int[,c(1,3,4)]
p.typechange.d<-c(summary(mod.typechange.death)$logtest[3],
                  summary(mod.typechange.death)$coeff[,5])

hr.typechangem.d<-summary(mod.typechange.m.death)$conf.int[,c(1,3,4)]
p.typechangem.d<-c(summary(mod.typechange.m.death)$logtest[3],
                  summary(mod.typechange.m.death)$coeff[,5])

init.reason.cat3<-ifelse(d$init.reason.cat=="toxicity"&d$init.reason.cat2=="Hematological toxicity (anemia etc)",
                         "toxicity-hematological",
                         ifelse(d$init.reason.cat=="toxicity","toxicity-other",
                                as.character(d$init.reason.cat)))
init.reason.cat3<-factor(init.reason.cat3,
                         levels=c("toxicity-other","toxicity-hematological","failure","other","unknown"))
mod.initreas3.death<-coxph(Surv(time,death1)~init.reason.cat3+strata(site))
hr.toxicity.hematological<-summary(mod.initreas3.death)$conf.int[1,c(1,3,4)]

save(hr.male.d,hr.age.d,hr.cd41.d,hr.cd42.d,hr.year2.d,hr.lengthart1.d,hr.initreas.d,hr.ndrugs.d,hr.ndrugscat.d,hr.typechange.d,hr.typechangem.d,hr.aids.d,
      p.male.d, p.age.d, p.cd41.d, p.cd42.d, p.year2.d, p.lengthart1.d, p.initreas.d, p.ndrugs.d, p.ndrugscat.d, p.typechange.d, p.typechangem.d, p.aids.d,
     hr.toxicity.hematological,p.delta.cd4.d,hr.delta.cd4.d,
     file="hr-death-unadjust.Rda")


#### Multiple imputation for nadir CD4 at first HAART and CD4 at start of second regimen

library(mi)

dd<-datadist(time.change2,change2,site,male,age2,cd41,cd42,year2,time.since.haart.y,init.reason.cat,
             num.change.cat,classify.type.arv.change,classify.type.arv.change.m,aids.enrollment)
options(datadist="dd")

d.analysis<-data.frame(male,age2,sqrt(cd41),sqrt(cd42),year2,time.since.haart.y,init.reason.cat,num.change.cat,n.change,site,
                       log(time),death1,log(time)*death1,log(time.change2),change2,log(time.change2)*change2,aids.enrollment,
                       change2.fail,change2.tox)
         # didn't include classify.type.arv into imputation model

M<-10
IMP<-mi(d.analysis,n.imp=M,seed=20130130)     # The actual imputation


dd<-datadist(data.frame(mi.data.frame(IMP,m=1),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m,init.reason.cat3,
                        cd4.change=mi.data.frame(IMP,m=1)$sqrt.cd42.^2-mi.data.frame(IMP,m=1)$sqrt.cd41.^2))
options(datadist="dd")
ests.primary<-ses.primary<-matrix(NA,M,19)
ests.extra<-ses.extra<-matrix(NA,M,16)
Pars<-matrix(NA,M,17)
VarCov<-matrix(NA,M,17^2)
Pars1<-matrix(NA,M,16)
VarCov1<-matrix(NA,M,16^2)
Pars3<-matrix(NA,M,22)
VarCov3<-matrix(NA,M,22^2)
Pars4<-matrix(NA,M,19)
VarCov4<-matrix(NA,M,19^2)
Pars5<-matrix(NA,M,17)
VarCov5<-matrix(NA,M,17^2)
ests.extra5<-ses.extra5<-NULL
ests.delta.cd4<-ses.delta.cd4<-matrix(NA,M,20)
for (i in 1:M) {
  d.imp<-data.frame(mi.data.frame(IMP,m=i),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m,init.reason.cat3,
                    cd4.change=mi.data.frame(IMP,m=i)$sqrt.cd42.^2-mi.data.frame(IMP,m=i)$sqrt.cd41.^2)
  #   
#   
#   dd<-datadist(d.imp)
#   options(datadist="dd")
  mod<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site),data=d.imp,x=TRUE,y=TRUE,survival=TRUE)

#   mod.strat.reason<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
#                site+strat(init.reason.cat),data=d.imp,x=TRUE,y=TRUE,survival=TRUE)

  #phtest<-cox.zph(mod, transform='log') 
  stuff1<-summary(mod,age2=c(40,20),sqrt.cd41.=c(sqrt(350),sqrt(50)),sqrt.cd42.=c(sqrt(350),sqrt(50)),year2=c(2004,2005),init.reason.cat="toxicity",
                  time.since.haart.y=c(3/12,6/12))[c("male","age2","aids.enrollment","sqrt.cd41.","sqrt.cd42.","year2","time.since.haart.y",
                                                     "init.reason.cat - failure:toxicity","init.reason.cat - other:toxicity",
                                                     "init.reason.cat - unknown:toxicity"),c(4,5)]
  stuff2<-summary(mod,age2=c(40,30),sqrt.cd41.=c(sqrt(350),sqrt(100)),sqrt.cd42.=c(sqrt(350),sqrt(100)),time.since.haart.y=c(3/12,1))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff3<-summary(mod,age2=c(40,50),sqrt.cd41.=c(sqrt(350),sqrt(200)),sqrt.cd42.=c(sqrt(350),sqrt(200)),time.since.haart.y=c(3/12,2))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff4<-summary(mod,time.since.haart.y=c(3/12,3))[c("time.since.haart.y"),c(4,5)]
  
  ans<-rbind(stuff1["male",],
             stuff1["age2",],
             stuff2["age2",],
             stuff3["age2",],
             stuff1["aids.enrollment",],
             stuff1["sqrt.cd41.",],
             stuff2["sqrt.cd41.",],
             stuff3["sqrt.cd41.",],
             stuff1["sqrt.cd42.",],
             stuff2["sqrt.cd42.",],
             stuff3["sqrt.cd42.",],
             stuff1["year2",],
             stuff1["time.since.haart.y",],
             stuff2["time.since.haart.y",],
             stuff3["time.since.haart.y",],
             stuff4,
             stuff1["init.reason.cat - failure:toxicity",],
             stuff1["init.reason.cat - other:toxicity",],
             stuff1["init.reason.cat - unknown:toxicity",])
  
  ests.primary[i,]<-ans[,1]
  ses.primary[i,]<-ans[,2]
  
  Pars[i,]<-mod$coeff
  VarCov[i,]<-matrix(mod$var,nrow=1)
  
  which.age<-which(names(mod$coeff)%in%c("age2","age2'","age2''"))
  which.cd41<-which(names(mod$coeff)%in%c("sqrt.cd41.","sqrt.cd41.'","sqrt.cd41.''"))
  which.cd42<-which(names(mod$coeff)%in%c("sqrt.cd42.","sqrt.cd42.'","sqrt.cd42.''"))
  which.tsh<-which(names(mod$coeff)%in%c("time.since.haart.y","time.since.haart.y'"))
  which.irc<-which(names(mod$coeff)%in%c("init.reason.cat=failure","init.reason.cat=other","init.reason.cat=unknown"))
  
  
  ####  Now the additional models
  
  mod1<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                                          num.change.cat+strat(site),data=d.imp)
  
  stuff.mod1<-summary(mod1)[c("num.change.cat - Single Drug Addition/Deletion:Single Drug Substitution",
                              "num.change.cat - Multidrug Change:Single Drug Substitution"),c(4,5)]
  
  
  mod2<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                                        n.change+strat(site),data=d.imp)
  stuff.mod2<-summary(mod2,n.change=c(1,2))["n.change",c(4,5)]
  
  mod3<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                                        type.change+strat(site),data=d.imp)
  stuff.mod3<-summary(mod3)[c("type.change - NNRTI to NNRTI; NNRTI switched:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to NNRTI; changes in NNRTI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; NRTI(s) switched, added, or removed:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; PI switched, added, removed, boosted, or unboosted:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; changes in PI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to PI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to NNRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - Other:NNRTI to NNRTI; NRTI(s) switched, added, or removed"),c(4,5)]

  
  mod4<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                                        type.change.m+strat(site),data=d.imp)
  stuff.mod4<-summary(mod4)[c("type.change.m - Change of NNRTI:Change of NRTI",
                              "type.change.m - Change of NRTI and NNRTI:Change of NRTI",
                              "type.change.m - Change of PI:Change of NRTI",
                              "type.change.m - Change of NRTI and PI:Change of NRTI",
                              "type.change.m - Other:Change of NRTI"),c(4,5)]
  
  mod5<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat3+strat(site),data=d.imp)
  junky<-summary(mod5,init.reason.cat3="toxicity-other")[c("init.reason.cat3 - toxicity-hematological:toxicity-other"),c(4,5)]
  ests.extra5[i]<-junky[1]
  ses.extra5[i]<-junky[2]
  
  modjunk<-coxph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site),data=d.imp)
  mod6<-coxph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat*year2+strat(site),data=d.imp)
  pval.inter[i]<-anova(mod6,modjunk)[2,4]
  
  ests.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,1]
  ses.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,2]

#####  New stuff added  
   mod.cd4.change<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(cd4.change,4)+
                      rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                      init.reason.cat+strat(site),data=d.imp)

   stuff1<-summary(mod.cd4.change,age2=c(40,20),cd4.change=c(0,-50),sqrt.cd42.=c(sqrt(350),sqrt(50)),year2=c(2004,2005),init.reason.cat="toxicity",
                   time.since.haart.y=c(3/12,6/12))[c("male","age2","aids.enrollment","cd4.change","sqrt.cd42.","year2","time.since.haart.y",
                                                   "init.reason.cat - failure:toxicity","init.reason.cat - other:toxicity",
                                                   "init.reason.cat - unknown:toxicity"),c(4,5)]
   stuff2<-summary(mod.cd4.change,age2=c(40,30),cd4.change=c(0,100),sqrt.cd42.=c(sqrt(350),sqrt(100)),time.since.haart.y=c(3/12,1))[
                  c("age2","cd4.change","sqrt.cd42.","time.since.haart.y"),c(4,5)]
   stuff3<-summary(mod.cd4.change,age2=c(40,50),cd4.change=c(0,200),sqrt.cd42.=c(sqrt(350),sqrt(200)),time.since.haart.y=c(3/12,2))[
                  c("age2","cd4.change","sqrt.cd42.","time.since.haart.y"),c(4,5)]
   stuff4<-summary(mod.cd4.change,cd4.change=c(0,300),time.since.haart.y=c(3/12,3))[c("cd4.change","time.since.haart.y"),c(4,5)]

   ans.delta.cd4<-rbind(stuff1["male",],
              stuff1["age2",],
              stuff2["age2",],
              stuff3["age2",],
              stuff1["aids.enrollment",],
              stuff1["cd4.change",],
              stuff2["cd4.change",],
              stuff3["cd4.change",],
              stuff4["cd4.change",],
              stuff1["sqrt.cd42.",],
              stuff2["sqrt.cd42.",],
              stuff3["sqrt.cd42.",],
              stuff1["year2",],
              stuff1["time.since.haart.y",],
              stuff2["time.since.haart.y",],
              stuff3["time.since.haart.y",],
              stuff4["time.since.haart.y",],
              stuff1["init.reason.cat - failure:toxicity",],
              stuff1["init.reason.cat - other:toxicity",],
              stuff1["init.reason.cat - unknown:toxicity",])

    ests.delta.cd4[i,]<-ans.delta.cd4[,1]
    ses.delta.cd4[i,]<-ans.delta.cd4[,2]

    which1.age<-which(names(mod.cd4.change$coeff)%in%c("age2","age2'","age2''"))
    which1.delta.cd4<-which(names(mod.cd4.change$coeff)%in%c("cd4.change","cd4.change'","cd4.change''"))
    which1.cd42<-which(names(mod.cd4.change$coeff)%in%c("sqrt.cd42.","sqrt.cd42.'","sqrt.cd42.''"))
    which1.tsh<-which(names(mod.cd4.change$coeff)%in%c("time.since.haart.y","time.since.haart.y'"))
    which1.irc<-which(names(mod.cd4.change$coeff)%in%c("init.reason.cat=failure","init.reason.cat=other","init.reason.cat=unknown"))

    Pars5[i,]<-mod.cd4.change$coeff
    VarCov5[i,]<-matrix(mod.cd4.change$var,nrow=1)
#####

  
  Pars1[i,]<-mod1$coeff
  VarCov1[i,]<-matrix(mod1$var,nrow=1)
  
  which.tc1<-which(names(mod1$coeff)%in%c("num.change.cat=Single Drug Addition/Deletion",
                                         "num.change.cat=Multidrug Change"))
  
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc3<-which(names(mod3$coeff)%in%c("type.change=NNRTI to NNRTI; NNRTI switched",
                                         "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                                         "type.change=PI to PI; NRTI(s) switched, added, or removed",
                                         "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                                         "type.change=PI to PI; changes in PI and NRTI",
                                         "type.change=NNRTI to PI",                                             
                                         "type.change=PI to NNRTI",
                                         "type.change=Other"))
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc4<-which(names(mod4$coeff)%in%c("type.change.m=Change of NNRTI",
                                          "type.change.m=Change of NRTI and NNRTI",                   
                                          "type.change.m=Change of PI",
                                          "type.change.m=Change of NRTI and PI",
                                          "type.change.m=Other"))
  Pars4[i,]<-mod4$coeff
  VarCov4[i,]<-matrix(mod4$var,nrow=1)
  
  
}

ests<-cbind(ests.primary,ests.extra,ests.extra5,ests.delta.cd4)
ses<-cbind(ses.primary,ses.extra,ses.extra5,ses.delta.cd4)

log.hr<-apply(ests,2,mean)
ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
hr<-exp(log.hr)
hr.lower<-exp(log.hr-1.96*ses.log.hr)
hr.upper<-exp(log.hr+1.96*ses.log.hr)
p.val<-2*pnorm(-abs(log.hr/ses.log.hr))


mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=17,ncol=17))
mean.Pars<-apply(Pars,2,mean)
pval.age.d<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
pval.cd41.d<-1-pchisq(mean.Pars[which.cd41]%*%mi.information[which.cd41,which.cd41]%*%mean.Pars[which.cd41],length(which.cd41))
pval.cd42.d<-1-pchisq(mean.Pars[which.cd42]%*%mi.information[which.cd42,which.cd42]%*%mean.Pars[which.cd42],length(which.cd42))
pval.time.since.haart.d<-1-pchisq(mean.Pars[which.tsh]%*%mi.information[which.tsh,which.tsh]%*%mean.Pars[which.tsh],length(which.tsh))
pval.init.reason.cat.d<-1-pchisq(mean.Pars[which.irc]%*%mi.information[which.irc,which.irc]%*%mean.Pars[which.irc],length(which.irc))

mi.information1<-solve(matrix(apply(VarCov1,2,mean)+(M+1)*apply(VarCov1,2,var)/M,nrow=16,ncol=16))
mean.Pars1<-apply(Pars1,2,mean)
pval.num.change.cat.d<-1-pchisq(mean.Pars1[which.tc1]%*%mi.information1[which.tc1,which.tc1]%*%mean.Pars1[which.tc1],length(which.tc1))

mi.information3<-solve(matrix(apply(VarCov3,2,mean)+(M+1)*apply(VarCov3,2,var)/M,nrow=22,ncol=22))
mean.Pars3<-apply(Pars3,2,mean)
pval.type.change.d<-1-pchisq(mean.Pars3[which.tc3]%*%mi.information3[which.tc3,which.tc3]%*%mean.Pars3[which.tc3],length(which.tc3))

mi.information4<-solve(matrix(apply(VarCov4,2,mean)+(M+1)*apply(VarCov4,2,var)/M,nrow=19,ncol=19))
mean.Pars4<-apply(Pars4,2,mean)
pval.type.change.m.d<-1-pchisq(mean.Pars4[which.tc4]%*%mi.information4[which.tc4,which.tc4]%*%mean.Pars4[which.tc4],length(which.tc4))


mi.information5<-solve(matrix(apply(VarCov5,2,mean)+(M+1)*apply(VarCov5,2,var)/M,nrow=17,ncol=17))
mean.Pars5<-apply(Pars5,2,mean)
pval.age.d5<-1-pchisq(mean.Pars5[which1.age]%*%mi.information5[which1.age,which1.age]%*%mean.Pars5[which1.age],length(which1.age))
pval.delta.cd4.d5<-1-pchisq(mean.Pars5[which1.delta.cd4]%*%mi.information5[which1.delta.cd4,which1.delta.cd4]%*%mean.Pars5[which1.delta.cd4],length(which1.delta.cd4))
pval.cd42.d5<-1-pchisq(mean.Pars5[which1.cd42]%*%mi.information5[which1.cd42,which1.cd42]%*%mean.Pars5[which1.cd42],length(which1.cd42))
pval.time.since.haart.d5<-1-pchisq(mean.Pars5[which1.tsh]%*%mi.information5[which1.tsh,which1.tsh]%*%mean.Pars5[which1.tsh],length(which1.tsh))
pval.init.reason.cat.d5<-1-pchisq(mean.Pars5[which1.irc]%*%mi.information5[which1.irc,which1.irc]%*%mean.Pars5[which1.irc],length(which1.irc))


hr.adj.d<-data.frame(label=c("male","age2 20:40","age2 30:40","age2 50:40","aids.enrollment",
                             "cd41 50:350","cd41 100:350","cd41 200:350","cd42 50:350","cd42 100:350","cd42 200:350",
                             "year2","time.since.haart 6:3","time.since.haart 12:3","time.since.haart 24:3","time.since.haart 36:3",
                             "init.reason.cat failure:toxicity","init.reason.cat other:toxicity","init.reason.cat unknown:toxicity",
                             "num.change.cat single drug addition","num.change.cat multidrug change",
                             "n.change",
                             "type.change=NNRTI to NNRTI; NNRTI switched",
                             "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                             "type.change=PI to PI; NRTI(s) switched, added, or removed",
                             "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                             "type.change=PI to PI; changes in PI and NRTI",
                             "type.change=NNRTI to PI",                                             
                             "type.change=PI to NNRTI",
                             "type.change=Other",
                             "type.change.m=NNRTI",
                             "type.change.m=NRTI and NNRTI",
                             "type.change.m=PI",
                             "type.change.m=NRTI and PI",
                             "type.change.m=Other",
                             "toxicity-hematological",
                             "male mod.delta.cd4","age2 20:40 mod.delta.cd4","age2 30:40 mod.delta.cd4","age2 50:40 mod.delta.cd4",
                             "aids.enrollment mod.delta.cd4",
                             "cd4.change -50:0 mod.delta.cd4","cd4.change 100:0 mod.delta.cd4","cd4.change 200:0 mod.delta.cd4","cd4.change 300:0 mod.delta.cd4",
                             "cd42 50:350 mod.delta.cd4","cd42 100:350 mod.delta.cd4","cd42 200:350 mod.delta.cd4",
                             "year2 mod.delta.cd4","time.since.haart 6:3 mod.delta.cd4","time.since.haart 12:3 mod.delta.cd4",
                             "time.since.haart 24:3 mod.delta.cd4","time.since.haart 36:3 mod.delta.cd4",
                             "init.reason.cat failure:toxicity mod.delta.cd4","init.reason.cat other:toxicity mod.delta.cd4",
                             "init.reason.cat unknown:toxicity mod.delta.cd4"),
           cbind(hr,hr.lower,hr.upper,p.val))
pval.inter.reason.calendar.d<-mean(pval.inter)  ### Very crude p-value for this interaction test


save(hr.adj.d,pval.age.d,pval.cd41.d,pval.cd42.d,pval.time.since.haart.d,pval.init.reason.cat.d,pval.num.change.cat.d,pval.type.change.d,
     pval.type.change.m.d,pval.inter.reason.calendar.d,pval.age.d5,pval.delta.cd4.d5,pval.cd42.d5,pval.time.since.haart.d5,pval.init.reason.cat.d5,
     file="hr-death-adjust.Rda")



####  Analyses with individual regimens

r2.3tc<-d$r2.3tc
r2.ftc<-d$r2.ftc
r2.efv<-d$r2.efv
r2.nvp<-d$r2.nvp
r2.abc<-d$r2.abc
r2.azt<-d$r2.azt
r2.d4t<-d$r2.d4t
r2.ddi<-d$r2.ddi
r2.tdf<-d$r2.tdf
r2.atv<-d$r2.atv
r2.sqv<-d$r2.sqv
r2.nfv<-d$r2.nfv
r2.lpv<-d$r2.lpv
r2.idv<-d$r2.idv

lhr2.est<-lhr2.ses<-matrix(NA,14,M)
lhr2A.est<-lhr2A.ses<-matrix(NA,8,M)
lhr2B.est<-lhr2B.ses<-matrix(NA,4,M)
for (i in 1:M){
  data.frame1<-data.frame(mi.data.frame(IMP,m=i),
                        r2.3tc,r2.ftc,r2.efv,r2.nvp,r2.abc,r2.azt,r2.d4t,r2.ddi,r2.tdf,r2.atv,r2.sqv,r2.nfv,r2.lpv,r2.idv,
                        second.class=d$second.class)
  dd<-datadist(data.frame1)
  options(datadist="dd")

  mod<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
           init.reason.cat+strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  
  mod1<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
           strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  mod2<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.3tc,data=data.frame1)
  mod3<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.ftc,data=data.frame1)
  mod4<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.efv,data=data.frame1)
  mod5<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.nvp,data=data.frame1)
  mod6<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.abc,data=data.frame1)
  mod7<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.azt,data=data.frame1)
  mod8<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.d4t,data=data.frame1)
  mod9<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
            init.reason.cat+strat(site)+r2.ddi,data=data.frame1)
  mod10<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.tdf,data=data.frame1)
  mod11<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.atv,data=data.frame1)
  mod12<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.sqv,data=data.frame1)
  mod13<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.nfv,data=data.frame1)
  mod14<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.lpv,data=data.frame1)
  mod15<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.idv,data=data.frame1)

  lhr2.3tc<-summary(mod2)[c(15),c(4,5)]
  lhr2.ftc<-summary(mod3)[c(15),c(4,5)]
  lhr2.efv<-summary(mod4)[c(15),c(4,5)]
  lhr2.nvp<-summary(mod5)[c(15),c(4,5)]
  lhr2.abc<-summary(mod6)[c(15),c(4,5)]
  lhr2.azt<-summary(mod7)[c(15),c(4,5)]
  lhr2.d4t<-summary(mod8)[c(15),c(4,5)]
  lhr2.ddi<-summary(mod9)[c(15),c(4,5)]
  lhr2.tdf<-summary(mod10)[c(15),c(4,5)]
  lhr2.atv<-summary(mod11)[c(15),c(4,5)]
  lhr2.sqv<-summary(mod12)[c(15),c(4,5)]  
  lhr2.nfv<-summary(mod13)[c(15),c(4,5)]
  lhr2.lpv<-summary(mod14)[c(15),c(4,5)]
  lhr2.idv<-summary(mod15)[c(15),c(4,5)]

  lhr2.est[,i]<-rbind(lhr2.3tc[1],lhr2.ftc[1],lhr2.efv[1],lhr2.nvp[1],lhr2.abc[1],lhr2.azt[1],
                      lhr2.d4t[1],lhr2.ddi[1],lhr2.tdf[1],lhr2.atv[1],lhr2.sqv[1],lhr2.nfv[1],lhr2.lpv[1],lhr2.idv[1])
  lhr2.ses[,i]<-rbind(lhr2.3tc[2],lhr2.ftc[2],lhr2.efv[2],lhr2.nvp[2],lhr2.abc[2],lhr2.azt[2],
                      lhr2.d4t[2],lhr2.ddi[2],lhr2.tdf[2],lhr2.atv[2],lhr2.sqv[2],lhr2.nfv[2],lhr2.lpv[2],lhr2.idv[2])

  
  mod.nnrti<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.efv,data=data.frame1, subset=(r2.efv==1|r2.nvp==1)&!(r2.efv==1&r2.nvp==1))
  mod.nrti<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                  init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi)&(r2.abc+r2.azt+r2.d4t+r2.tdf+r2.ddi==1))
  mod.nrti2<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                 subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi))
  mod.bpi<-cph(Surv(exp(log.time.),death1)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                 init.reason.cat+strat(site)+r2.atv+r2.idv+r2.sqv,data=data.frame1, 
               subset=(r2.atv==1|r2.nfv==1|r2.idv==1|r2.lpv==1|r2.sqv==1)&second.class=="BOOSTED PI"&(r2.atv+r2.nfv+r2.idv+r2.lpv+r2.sqv==1))
  ####  NFV removed because of singular matrix
  
  lhr2A.efv<-summary(mod.nnrti)[c(15),c(4,5)]
  lhr2A.abc<-summary(mod.nrti)[c(15),c(4,5)]
  lhr2A.d4t<-summary(mod.nrti)[c(17),c(4,5)]
  lhr2A.ddi<-summary(mod.nrti)[c(21),c(4,5)]
  lhr2A.tdf<-summary(mod.nrti)[c(19),c(4,5)]
  lhr2B.abc<-summary(mod.nrti2)[c(15),c(4,5)]
  lhr2B.d4t<-summary(mod.nrti2)[c(17),c(4,5)]
  lhr2B.ddi<-summary(mod.nrti2)[c(21),c(4,5)]
  lhr2B.tdf<-summary(mod.nrti2)[c(19),c(4,5)]
  lhr2A.atv<-summary(mod.bpi)[c(15),c(4,5)]
  lhr2A.idv<-summary(mod.bpi)[c(17),c(4,5)]
  lhr2A.sqv<-summary(mod.bpi)[c(19),c(4,5)]  
  
  lhr2A.est[,i]<-rbind(lhr2A.efv[1],lhr2A.abc[1],lhr2A.d4t[1],lhr2A.ddi[1],lhr2A.tdf[1],lhr2A.atv[1],lhr2A.sqv[1],lhr2A.idv[1])
  lhr2A.ses[,i]<-rbind(lhr2A.efv[2],lhr2A.abc[2],lhr2A.d4t[2],lhr2A.ddi[2],lhr2A.tdf[2],lhr2A.atv[2],lhr2A.sqv[2],lhr2A.idv[2])
  
  lhr2B.est[,i]<-rbind(lhr2B.abc[1],lhr2B.d4t[1],lhr2B.ddi[1],lhr2B.tdf[1])
  lhr2B.ses[,i]<-rbind(lhr2B.abc[2],lhr2B.d4t[2],lhr2B.ddi[2],lhr2B.tdf[2])
  
  
}

log.hr.reg<-apply(lhr2.est,1,mean)
ses.log.hr.reg<-sqrt(apply(lhr2.ses^2,1,mean)+(M+1)*apply(lhr2.est,1,var)/M)
hr.reg<-exp(log.hr.reg)
hr.reg.lower<-exp(log.hr.reg-1.96*ses.log.hr.reg)
hr.reg.upper<-exp(log.hr.reg+1.96*ses.log.hr.reg)
p.val.reg<-2*pnorm(-abs(log.hr.reg/ses.log.hr.reg))

hr.reg<-cbind(hr.reg,hr.reg.lower,hr.reg.upper,p.val.reg)
names.hr.reg<-c("3tc","ftc","efv","nvp","abc","azt","d4t","ddi","tdf","atv","sqv","nfv","lpv","idv")


log.hr.regA<-apply(lhr2A.est,1,mean)
ses.log.hr.regA<-sqrt(apply(lhr2A.ses^2,1,mean)+(M+1)*apply(lhr2A.est,1,var)/M)
hr.regA<-exp(log.hr.regA)
hr.reg.lowerA<-exp(log.hr.regA-1.96*ses.log.hr.regA)
hr.reg.upperA<-exp(log.hr.regA+1.96*ses.log.hr.regA)
p.val.regA<-2*pnorm(-abs(log.hr.regA/ses.log.hr.regA))

hr.regA<-cbind(hr.regA,hr.reg.lowerA,hr.reg.upperA,p.val.regA)
names.hr.regA<-c("efv","abc","d4t","ddi","tdf","atv","sqv","idv")

log.hr.regB<-apply(lhr2B.est,1,mean)
ses.log.hr.regB<-sqrt(apply(lhr2B.ses^2,1,mean)+(M+1)*apply(lhr2B.est,1,var)/M)
hr.regB<-exp(log.hr.regB)
hr.reg.lowerB<-exp(log.hr.regB-1.96*ses.log.hr.regB)
hr.reg.upperB<-exp(log.hr.regB+1.96*ses.log.hr.regB)
p.val.regB<-2*pnorm(-abs(log.hr.regB/ses.log.hr.regB))

hr.regB<-cbind(hr.regB,hr.reg.lowerB,hr.reg.upperB,p.val.regB)
names.hr.regB<-c("abc","d4t","ddi","tdf")


save(hr.reg,names.hr.reg,hr.regA,names.hr.regA,hr.regB,names.hr.regB,file="hr-death-adjust-reg.Rda")





######################################################################
##### Time to change regimen HR

dd<-datadist(time.change2,change2,site,male,age2,cd41,cd42,year2,time.since.haart.y,init.reason.cat,num.change.cat,classify.type.arv.change,aids.enrollment)
options(datadist="dd")

mod.male.change<-coxph(Surv(time.change2,change2)~male+strata(site))
mod.age.change<-cph(Surv(time.change2,change2)~rcs(age2,4)+strat(site))
mod.aids.change<-coxph(Surv(time.change2,change2)~aids.enrollment+strata(site))
mod.cd41.change<-cph(Surv(time.change2,change2)~rcs(sqrt(cd41),4)+strat(site))
mod.cd42.change<-cph(Surv(time.change2,change2)~sqrt(cd42)+strat(site))  #removed nonlinear piece because cph having hard time and test for non-linearity was p>0.7; coxph worked fine.
mod.year2.change<-coxph(Surv(time.change2,change2)~year2+strata(site))   #removed non-linear piece
mod.lengthart1.change<-cph(Surv(time.change2,change2)~rcs(log(time.since.haart.y),3)+strat(site))
mod.initreas.change<-coxph(Surv(time.change2,change2)~init.reason.cat+strata(site))
mod.ndrugs.change<-coxph(Surv(time.change2,change2)~n.change+strata(site))
mod.ndrugscat.change<-coxph(Surv(time.change2,change2)~num.change.cat+strata(site))
mod.typechange.change<-coxph(Surv(time.change2,change2)~classify.type.arv.change+strata(site))
mod.typechange.m.change<-coxph(Surv(time.change2,change2)~classify.type.arv.change.m+strata(site))



hr.male.c<-summary(mod.male.change)$conf.int[c(1,3,4)]
p.male.c<-summary(mod.male.change)$logtest[3]

p.age.c<-anova(mod.age.change)[3,3]
hr.age.c<-rbind(summary(mod.age.change,age2=c(40,20))[2,c(4,6,7)],
                summary(mod.age.change,age2=c(40,30))[2,c(4,6,7)],
                summary(mod.age.change,age2=c(40,50))[2,c(4,6,7)])

hr.aids.c<-summary(mod.aids.change)$conf.int[c(1,3,4)]
p.aids.c<-summary(mod.aids.change)$logtest[3]

p.cd41.c<-anova(mod.cd41.change)[3,3]
hr.cd41.c<-rbind(summary(mod.cd41.change,cd41=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd41.change,cd41=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd41.change,cd41=c(350,200))[2,c(4,6,7)])

p.cd42.c<-anova(mod.cd42.change)[2,3]
hr.cd42.c<-rbind(summary(mod.cd42.change,cd42=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd42.change,cd42=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd42.change,cd42=c(350,200))[2,c(4,6,7)])

hr.year2.c<-summary(mod.year2.change)$conf.int[c(1,3,4)]
p.year2.c<-summary(mod.year2.change)$logtest[3]

p.lengthart1.c<-anova(mod.lengthart1.change)[3,3]
hr.lengthart1.c<-rbind(summary(mod.lengthart1.change,time.since.haart.y=c(3/12,6/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.change,time.since.haart.y=c(3/12,12/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.change,time.since.haart.y=c(3/12,2))[2,c(4,6,7)],
                       summary(mod.lengthart1.change,time.since.haart.y=c(3/12,3))[2,c(4,6,7)])

hr.initreas.c<-summary(mod.initreas.change)$conf.int[,c(1,3,4)]
p.initreas.c<-c(summary(mod.initreas.change)$logtest[3],
                summary(mod.initreas.change)$coeff[,5])

hr.ndrugs.c<-summary(mod.ndrugs.change)$conf.int[c(1,3,4)]
p.ndrugs.c<-summary(mod.ndrugs.change)$logtest[3]

hr.ndrugscat.c<-summary(mod.ndrugscat.change)$conf.int[,c(1,3,4)]
p.ndrugscat.c<-c(summary(mod.ndrugscat.change)$logtest[3],
                 summary(mod.ndrugscat.change)$coeff[,5])

hr.typechange.c<-summary(mod.typechange.change)$conf.int[,c(1,3,4)]
p.typechange.c<-c(summary(mod.typechange.change)$logtest[3],
                  summary(mod.typechange.change)$coeff[,5])

hr.typechangem.c<-summary(mod.typechange.m.change)$conf.int[,c(1,3,4)]
p.typechangem.c<-c(summary(mod.typechange.m.change)$logtest[3],
                   summary(mod.typechange.m.change)$coeff[,5])


save(hr.male.c,hr.age.c,hr.cd41.c,hr.cd42.c,hr.year2.c,hr.lengthart1.c,hr.initreas.c,hr.ndrugs.c,hr.ndrugscat.c,hr.typechange.c,hr.aids.c,
     hr.typechangem.c,
     p.male.c, p.age.c, p.cd41.c, p.cd42.c, p.year2.c, p.lengthart1.c, p.initreas.c, p.ndrugs.c, p.ndrugscat.c, p.typechange.c,p.aids.c,
     p.typechangem.c,
     file="hr-change-unadjust.Rda")



###  MI for changing


dd<-datadist(data.frame(mi.data.frame(IMP,m=1),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m))
options(datadist="dd")
ests.primary<-ses.primary<-matrix(NA,M,19)
ests.extra<-ses.extra<-matrix(NA,M,16)
Pars<-matrix(NA,M,17)
VarCov<-matrix(NA,M,17^2)
Pars1<-matrix(NA,M,16)
VarCov1<-matrix(NA,M,16^2)
Pars3<-matrix(NA,M,22)
VarCov3<-matrix(NA,M,22^2)
Pars4<-matrix(NA,M,19)
VarCov4<-matrix(NA,M,19^2)
for (i in 1:M) {
  d.imp<-data.frame(mi.data.frame(IMP,m=i),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m)
  #   
  #   dd<-datadist(d.imp)
  #   options(datadist="dd")
  mod<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site),data=d.imp)
  stuff1<-summary(mod,age2=c(40,20),sqrt.cd41.=c(sqrt(350),sqrt(50)),sqrt.cd42.=c(sqrt(350),sqrt(50)),year2=c(2004,2005),init.reason.cat="toxicity",
                  time.since.haart.y=c(3/12,6/12))[c("male","age2","aids.enrollment","sqrt.cd41.","sqrt.cd42.","year2","time.since.haart.y",
                                                     "init.reason.cat - failure:toxicity","init.reason.cat - other:toxicity",
                                                     "init.reason.cat - unknown:toxicity"),c(4,5)]
  stuff2<-summary(mod,age2=c(40,30),sqrt.cd41.=c(sqrt(350),sqrt(100)),sqrt.cd42.=c(sqrt(350),sqrt(100)),time.since.haart.y=c(3/12,1))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff3<-summary(mod,age2=c(40,50),sqrt.cd41.=c(sqrt(350),sqrt(200)),sqrt.cd42.=c(sqrt(350),sqrt(200)),time.since.haart.y=c(3/12,2))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff4<-summary(mod,time.since.haart.y=c(3/12,3))[c("time.since.haart.y"),c(4,5)]
  
  ans<-rbind(stuff1["male",],
             stuff1["age2",],
             stuff2["age2",],
             stuff3["age2",],
             stuff1["aids.enrollment",],
             stuff1["sqrt.cd41.",],
             stuff2["sqrt.cd41.",],
             stuff3["sqrt.cd41.",],
             stuff1["sqrt.cd42.",],
             stuff2["sqrt.cd42.",],
             stuff3["sqrt.cd42.",],
             stuff1["year2",],
             stuff1["time.since.haart.y",],
             stuff2["time.since.haart.y",],
             stuff3["time.since.haart.y",],
             stuff4,
             stuff1["init.reason.cat - failure:toxicity",],
             stuff1["init.reason.cat - other:toxicity",],
             stuff1["init.reason.cat - unknown:toxicity",])
  
  ests.primary[i,]<-ans[,1]
  ses.primary[i,]<-ans[,2]
  
  Pars[i,]<-mod$coeff
  VarCov[i,]<-matrix(mod$var,nrow=1)
  
  which.age<-which(names(mod$coeff)%in%c("age2","age2'","age2''"))
  which.cd41<-which(names(mod$coeff)%in%c("sqrt.cd41.","sqrt.cd41.'","sqrt.cd41.''"))
  which.cd42<-which(names(mod$coeff)%in%c("sqrt.cd42.","sqrt.cd42.'","sqrt.cd42.''"))
  which.tsh<-which(names(mod$coeff)%in%c("time.since.haart.y","time.since.haart.y'"))
  which.irc<-which(names(mod$coeff)%in%c("init.reason.cat=failure","init.reason.cat=other","init.reason.cat=unknown"))
  
  
  ####  Now the additional models
  
  mod1<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              num.change.cat+strat(site),data=d.imp)
  
  stuff.mod1<-summary(mod1)[c("num.change.cat - Single Drug Addition/Deletion:Single Drug Substitution",
                              "num.change.cat - Multidrug Change:Single Drug Substitution"),c(4,5)]
  
  
  mod2<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              n.change+strat(site),data=d.imp)
  stuff.mod2<-summary(mod2,n.change=c(1,2))["n.change",c(4,5)]
  
  mod3<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change+strat(site),data=d.imp)
  stuff.mod3<-summary(mod3)[c("type.change - NNRTI to NNRTI; NNRTI switched:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to NNRTI; changes in NNRTI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; NRTI(s) switched, added, or removed:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; PI switched, added, removed, boosted, or unboosted:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; changes in PI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to PI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to NNRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - Other:NNRTI to NNRTI; NRTI(s) switched, added, or removed"),c(4,5)]
  
  
  mod4<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change.m+strat(site),data=d.imp)
  stuff.mod4<-summary(mod4)[c("type.change.m - Change of NNRTI:Change of NRTI",
                              "type.change.m - Change of NRTI and NNRTI:Change of NRTI",
                              "type.change.m - Change of PI:Change of NRTI",
                              "type.change.m - Change of NRTI and PI:Change of NRTI",
                              "type.change.m - Other:Change of NRTI"),c(4,5)]
  
  
  
  ests.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,1]
  ses.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,2]
  
  
  
  Pars1[i,]<-mod1$coeff
  VarCov1[i,]<-matrix(mod1$var,nrow=1)
  
  which.tc1<-which(names(mod1$coeff)%in%c("num.change.cat=Single Drug Addition/Deletion",
                                          "num.change.cat=Multidrug Change"))
  
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc3<-which(names(mod3$coeff)%in%c("type.change=NNRTI to NNRTI; NNRTI switched",
                                          "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                                          "type.change=PI to PI; NRTI(s) switched, added, or removed",
                                          "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                                          "type.change=PI to PI; changes in PI and NRTI",
                                          "type.change=NNRTI to PI",                                             
                                          "type.change=PI to NNRTI",
                                          "type.change=Other"))
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc4<-which(names(mod4$coeff)%in%c("type.change.m=Change of NNRTI",
                                          "type.change.m=Change of NRTI and NNRTI",                   
                                          "type.change.m=Change of PI",
                                          "type.change.m=Change of NRTI and PI",
                                          "type.change.m=Other"))
  Pars4[i,]<-mod4$coeff
  VarCov4[i,]<-matrix(mod4$var,nrow=1)
  
  
}

ests<-cbind(ests.primary,ests.extra)
ses<-cbind(ses.primary,ses.extra)

log.hr<-apply(ests,2,mean)
ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
hr<-exp(log.hr)
hr.lower<-exp(log.hr-1.96*ses.log.hr)
hr.upper<-exp(log.hr+1.96*ses.log.hr)
p.val<-2*pnorm(-abs(log.hr/ses.log.hr))


mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=17,ncol=17))
mean.Pars<-apply(Pars,2,mean)
pval.age.c<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
pval.cd41.c<-1-pchisq(mean.Pars[which.cd41]%*%mi.information[which.cd41,which.cd41]%*%mean.Pars[which.cd41],length(which.cd41))
pval.cd42.c<-1-pchisq(mean.Pars[which.cd42]%*%mi.information[which.cd42,which.cd42]%*%mean.Pars[which.cd42],length(which.cd42))
pval.time.since.haart.c<-1-pchisq(mean.Pars[which.tsh]%*%mi.information[which.tsh,which.tsh]%*%mean.Pars[which.tsh],length(which.tsh))
pval.init.reason.cat.c<-1-pchisq(mean.Pars[which.irc]%*%mi.information[which.irc,which.irc]%*%mean.Pars[which.irc],length(which.irc))

mi.information1<-solve(matrix(apply(VarCov1,2,mean)+(M+1)*apply(VarCov1,2,var)/M,nrow=16,ncol=16))
mean.Pars1<-apply(Pars1,2,mean)
pval.num.change.cat.c<-1-pchisq(mean.Pars1[which.tc1]%*%mi.information1[which.tc1,which.tc1]%*%mean.Pars1[which.tc1],length(which.tc1))

mi.information3<-solve(matrix(apply(VarCov3,2,mean)+(M+1)*apply(VarCov3,2,var)/M,nrow=22,ncol=22))
mean.Pars3<-apply(Pars3,2,mean)
pval.type.change.c<-1-pchisq(mean.Pars3[which.tc3]%*%mi.information3[which.tc3,which.tc3]%*%mean.Pars3[which.tc3],length(which.tc3))

mi.information4<-solve(matrix(apply(VarCov4,2,mean)+(M+1)*apply(VarCov4,2,var)/M,nrow=19,ncol=19))
mean.Pars4<-apply(Pars4,2,mean)
pval.type.change.m.c<-1-pchisq(mean.Pars4[which.tc4]%*%mi.information4[which.tc4,which.tc4]%*%mean.Pars4[which.tc4],length(which.tc4))


hr.adj.c<-data.frame(label=c("male","age2 20:40","age2 30:40","age2 50:40","aids.enrollment",
                             "cd41 50:350","cd41 100:350","cd41 200:350","cd42 50:350","cd42 100:350","cd42 200:350",
                             "year2","time.since.haart 6:3","time.since.haart 12:3","time.since.haart 24:3","time.since.haart 36:3",
                             "init.reason.cat failure:toxicity","init.reason.cat other:toxicity","init.reason.cat unknown:toxicity",
                             "num.change.cat single drug addition","num.change.cat multidrug change",
                             "n.change",
                             "type.change=NNRTI to NNRTI; NNRTI switched",
                             "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                             "type.change=PI to PI; NRTI(s) switched, added, or removed",
                             "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                             "type.change=PI to PI; changes in PI and NRTI",
                             "type.change=NNRTI to PI",                                             
                             "type.change=PI to NNRTI",
                             "type.change=Other",
                             "type.change.m=NNRTI",
                             "type.change.m=NRTI and NNRTI",
                             "type.change.m=PI",
                             "type.change.m=NRTI and PI",
                             "type.change.m=Other"),
                     cbind(hr,hr.lower,hr.upper,p.val))


save(hr.adj.c,pval.age.c,pval.cd41.c,pval.cd42.c,pval.time.since.haart.c,pval.init.reason.cat.c,pval.num.change.cat.c,pval.type.change.c,
     pval.type.change.m.c,
     file="hr-change-adjust.Rda")



####  Analyses with individual regimens

lhr2.est<-lhr2.ses<-matrix(NA,14,M)
lhr2A.est<-lhr2A.ses<-matrix(NA,8,M)
lhr2B.est<-lhr2B.ses<-matrix(NA,4,M)
for (i in 1:M){
  data.frame1<-data.frame(mi.data.frame(IMP,m=i),
                          r2.3tc,r2.ftc,r2.efv,r2.nvp,r2.abc,r2.azt,r2.d4t,r2.ddi,r2.tdf,r2.atv,r2.sqv,r2.nfv,r2.lpv,r2.idv,
                          second.class=d$second.class)
  dd<-datadist(data.frame1)
  options(datadist="dd")
  
  mod<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  
  mod1<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  mod2<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.3tc,data=data.frame1)
  mod3<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ftc,data=data.frame1)
  mod4<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.efv,data=data.frame1)
  mod5<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.nvp,data=data.frame1)
  mod6<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.abc,data=data.frame1)
  mod7<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.azt,data=data.frame1)
  mod8<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.d4t,data=data.frame1)
  mod9<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ddi,data=data.frame1)
  mod10<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.tdf,data=data.frame1)
  mod11<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.atv,data=data.frame1)
  mod12<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.sqv,data=data.frame1)
  mod13<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.nfv,data=data.frame1)
  mod14<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.lpv,data=data.frame1)
  mod15<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.idv,data=data.frame1)
  
  lhr2.3tc<-summary(mod2)[c(15),c(4,5)]
  lhr2.ftc<-summary(mod3)[c(15),c(4,5)]
  lhr2.efv<-summary(mod4)[c(15),c(4,5)]
  lhr2.nvp<-summary(mod5)[c(15),c(4,5)]
  lhr2.abc<-summary(mod6)[c(15),c(4,5)]
  lhr2.azt<-summary(mod7)[c(15),c(4,5)]
  lhr2.d4t<-summary(mod8)[c(15),c(4,5)]
  lhr2.ddi<-summary(mod9)[c(15),c(4,5)]
  lhr2.tdf<-summary(mod10)[c(15),c(4,5)]
  lhr2.atv<-summary(mod11)[c(15),c(4,5)]
  lhr2.sqv<-summary(mod12)[c(15),c(4,5)]  
  lhr2.nfv<-summary(mod13)[c(15),c(4,5)]
  lhr2.lpv<-summary(mod14)[c(15),c(4,5)]
  lhr2.idv<-summary(mod15)[c(15),c(4,5)]
  
  lhr2.est[,i]<-rbind(lhr2.3tc[1],lhr2.ftc[1],lhr2.efv[1],lhr2.nvp[1],lhr2.abc[1],lhr2.azt[1],
                      lhr2.d4t[1],lhr2.ddi[1],lhr2.tdf[1],lhr2.atv[1],lhr2.sqv[1],lhr2.nfv[1],lhr2.lpv[1],lhr2.idv[1])
  lhr2.ses[,i]<-rbind(lhr2.3tc[2],lhr2.ftc[2],lhr2.efv[2],lhr2.nvp[2],lhr2.abc[2],lhr2.azt[2],
                      lhr2.d4t[2],lhr2.ddi[2],lhr2.tdf[2],lhr2.atv[2],lhr2.sqv[2],lhr2.nfv[2],lhr2.lpv[2],lhr2.idv[2])
  
  mod.nnrti<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.efv,data=data.frame1, subset=(r2.efv==1|r2.nvp==1)&!(r2.efv==1&r2.nvp==1))
  mod.nrti<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                  init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi)&(r2.abc+r2.azt+r2.d4t+r2.tdf+r2.ddi==1))
  mod.nrti2<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                 subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi))
  mod.bpi<-cph(Surv(exp(log.time.change2.),change2)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                 init.reason.cat+strat(site)+r2.atv+r2.idv+r2.sqv,data=data.frame1, 
               subset=(r2.atv==1|r2.nfv==1|r2.idv==1|r2.lpv==1|r2.sqv==1)&second.class=="BOOSTED PI"&(r2.atv+r2.nfv+r2.idv+r2.lpv+r2.sqv==1))
  ####  NFV removed because of singular matrix
  
  lhr2A.efv<-summary(mod.nnrti)[c(15),c(4,5)]
  lhr2A.abc<-summary(mod.nrti)[c(15),c(4,5)]
  lhr2A.d4t<-summary(mod.nrti)[c(17),c(4,5)]
  lhr2A.ddi<-summary(mod.nrti)[c(21),c(4,5)]
  lhr2A.tdf<-summary(mod.nrti)[c(19),c(4,5)]
  lhr2B.abc<-summary(mod.nrti2)[c(15),c(4,5)]
  lhr2B.d4t<-summary(mod.nrti2)[c(17),c(4,5)]
  lhr2B.ddi<-summary(mod.nrti2)[c(21),c(4,5)]
  lhr2B.tdf<-summary(mod.nrti2)[c(19),c(4,5)]
  lhr2A.atv<-summary(mod.bpi)[c(15),c(4,5)]
  lhr2A.idv<-summary(mod.bpi)[c(17),c(4,5)]
  lhr2A.sqv<-summary(mod.bpi)[c(19),c(4,5)]  
  
  lhr2A.est[,i]<-rbind(lhr2A.efv[1],lhr2A.abc[1],lhr2A.d4t[1],lhr2A.ddi[1],lhr2A.tdf[1],lhr2A.atv[1],lhr2A.sqv[1],lhr2A.idv[1])
  lhr2A.ses[,i]<-rbind(lhr2A.efv[2],lhr2A.abc[2],lhr2A.d4t[2],lhr2A.ddi[2],lhr2A.tdf[2],lhr2A.atv[2],lhr2A.sqv[2],lhr2A.idv[2])
  
  lhr2B.est[,i]<-rbind(lhr2B.abc[1],lhr2B.d4t[1],lhr2B.ddi[1],lhr2B.tdf[1])
  lhr2B.ses[,i]<-rbind(lhr2B.abc[2],lhr2B.d4t[2],lhr2B.ddi[2],lhr2B.tdf[2])
  
  
}

log.hr.reg<-apply(lhr2.est,1,mean)
ses.log.hr.reg<-sqrt(apply(lhr2.ses^2,1,mean)+(M+1)*apply(lhr2.est,1,var)/M)
hr.reg<-exp(log.hr.reg)
hr.reg.lower<-exp(log.hr.reg-1.96*ses.log.hr.reg)
hr.reg.upper<-exp(log.hr.reg+1.96*ses.log.hr.reg)
p.val.reg<-2*pnorm(-abs(log.hr.reg/ses.log.hr.reg))

hr.change.reg<-cbind(hr.reg,hr.reg.lower,hr.reg.upper,p.val.reg)
names.hr.change.reg<-c("3tc","ftc","efv","nvp","abc","azt","d4t","ddi","tdf","atv","sqv","nfv","lpv","idv")


log.hr.regA<-apply(lhr2A.est,1,mean)
ses.log.hr.regA<-sqrt(apply(lhr2A.ses^2,1,mean)+(M+1)*apply(lhr2A.est,1,var)/M)
hr.regA<-exp(log.hr.regA)
hr.reg.lowerA<-exp(log.hr.regA-1.96*ses.log.hr.regA)
hr.reg.upperA<-exp(log.hr.regA+1.96*ses.log.hr.regA)
p.val.regA<-2*pnorm(-abs(log.hr.regA/ses.log.hr.regA))

hr.change.regA<-cbind(hr.regA,hr.reg.lowerA,hr.reg.upperA,p.val.regA)
names.hr.change.regA<-c("efv","abc","d4t","ddi","tdf","atv","sqv","idv")

log.hr.regB<-apply(lhr2B.est,1,mean)
ses.log.hr.regB<-sqrt(apply(lhr2B.ses^2,1,mean)+(M+1)*apply(lhr2B.est,1,var)/M)
hr.regB<-exp(log.hr.regB)
hr.reg.lowerB<-exp(log.hr.regB-1.96*ses.log.hr.regB)
hr.reg.upperB<-exp(log.hr.regB+1.96*ses.log.hr.regB)
p.val.regB<-2*pnorm(-abs(log.hr.regB/ses.log.hr.regB))

hr.change.regB<-cbind(hr.regB,hr.reg.lowerB,hr.reg.upperB,p.val.regB)
names.hr.change.regB<-c("abc","d4t","ddi","tdf")


save(hr.change.reg,names.hr.change.reg,hr.change.regA,names.hr.change.regA,hr.change.regB,names.hr.change.regB,file="hr-change-reg.Rda")





#############  Changing due to toxicity


dd<-datadist(time.change2,change2,site,male,age2,cd41,cd42,year2,time.since.haart.y,init.reason.cat,num.change.cat,classify.type.arv.change,aids.enrollment)
options(datadist="dd")

mod.male.tox<-coxph(Surv(time.change2.tox,change2.tox)~male+strata(site))
mod.age.tox<-cph(Surv(time.change2.tox,change2.tox)~rcs(age2,4)+strat(site))
mod.aids.tox<-coxph(Surv(time.change2.tox,change2.tox)~aids.enrollment+strata(site))
mod.cd41.tox<-cph(Surv(time.change2.tox,change2.tox)~rcs(sqrt(cd41),4)+strat(site))
mod.cd42.tox<-cph(Surv(time.change2.tox,change2.tox)~rcs(sqrt(cd42),4)+strat(site))
mod.year2.tox<-coxph(Surv(time.change2.tox,change2.tox)~year2+strata(site))   #removed non-linear piece
mod.lengthart1.tox<-cph(Surv(time.change2.tox,change2.tox)~rcs(log(time.since.haart.y),3)+strat(site))
mod.initreas.tox<-coxph(Surv(time.change2.tox,change2.tox)~init.reason.cat+strata(site))
mod.ndrugs.tox<-coxph(Surv(time.change2.tox,change2.tox)~n.change+strata(site))
mod.ndrugscat.tox<-coxph(Surv(time.change2.tox,change2.tox)~num.change.cat+strata(site))
mod.typechange.tox<-coxph(Surv(time.change2.tox,change2.tox)~classify.type.arv.change+strata(site))
mod.typechange.m.tox<-coxph(Surv(time.change2.tox,change2.tox)~classify.type.arv.change.m+strata(site))

hr.male.t<-summary(mod.male.tox)$conf.int[c(1,3,4)]
p.male.t<-summary(mod.male.tox)$logtest[3]

p.age.t<-anova(mod.age.tox)[3,3]
hr.age.t<-rbind(summary(mod.age.tox,age2=c(40,20))[2,c(4,6,7)],
                summary(mod.age.tox,age2=c(40,30))[2,c(4,6,7)],
                summary(mod.age.tox,age2=c(40,50))[2,c(4,6,7)])

hr.aids.t<-summary(mod.aids.tox)$conf.int[c(1,3,4)]
p.aids.t<-summary(mod.aids.tox)$logtest[3]

p.cd41.t<-anova(mod.cd41.tox)[3,3]
hr.cd41.t<-rbind(summary(mod.cd41.tox,cd41=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd41.tox,cd41=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd41.tox,cd41=c(350,200))[2,c(4,6,7)])

p.cd42.t<-anova(mod.cd42.tox)[3,3]
hr.cd42.t<-rbind(summary(mod.cd42.tox,cd42=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd42.tox,cd42=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd42.tox,cd42=c(350,200))[2,c(4,6,7)])

hr.year2.t<-summary(mod.year2.tox)$conf.int[c(1,3,4)]
p.year2.t<-summary(mod.year2.tox)$logtest[3]

p.lengthart1.t<-anova(mod.lengthart1.tox)[3,3]
hr.lengthart1.t<-rbind(summary(mod.lengthart1.tox,time.since.haart.y=c(3/12,6/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.tox,time.since.haart.y=c(3/12,12/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.tox,time.since.haart.y=c(3/12,2))[2,c(4,6,7)],
                       summary(mod.lengthart1.tox,time.since.haart.y=c(3/12,3))[2,c(4,6,7)])

hr.initreas.t<-summary(mod.initreas.tox)$conf.int[,c(1,3,4)]
p.initreas.t<-c(summary(mod.initreas.tox)$logtest[3],
                summary(mod.initreas.tox)$coeff[,5])

hr.ndrugs.t<-summary(mod.ndrugs.tox)$conf.int[c(1,3,4)]
p.ndrugs.t<-summary(mod.ndrugs.tox)$logtest[3]

hr.ndrugscat.t<-summary(mod.ndrugscat.tox)$conf.int[,c(1,3,4)]
p.ndrugscat.t<-c(summary(mod.ndrugscat.tox)$logtest[3],
                 summary(mod.ndrugscat.tox)$coeff[,5])

hr.typechange.t<-summary(mod.typechange.tox)$conf.int[,c(1,3,4)]
p.typechange.t<-c(summary(mod.typechange.tox)$logtest[3],
                  summary(mod.typechange.tox)$coeff[,5])

hr.typechangem.t<-summary(mod.typechange.m.tox)$conf.int[,c(1,3,4)]
p.typechangem.t<-c(summary(mod.typechange.m.tox)$logtest[3],
                   summary(mod.typechange.m.tox)$coeff[,5])


save(hr.male.t,hr.age.t,hr.cd41.t,hr.cd42.t,hr.year2.t,hr.lengthart1.t,hr.initreas.t,hr.ndrugs.t,hr.ndrugscat.t,hr.typechange.t,hr.aids.t,
     hr.typechangem.t,
     p.male.t, p.age.t, p.cd41.t, p.cd42.t, p.year2.t, p.lengthart1.t, p.initreas.t, p.ndrugs.t, p.ndrugscat.t, p.typechange.t,p.aids.t,
     p.typechangem.t,
     file="hr-tox-unadjust.Rda")




#### Multiple imputation for nadir CD4 at first HAART and CD4 at start of second regimen


dd<-datadist(data.frame(mi.data.frame(IMP,m=1),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m))
options(datadist="dd")
ests.primary<-ses.primary<-matrix(NA,M,19)
ests.extra<-ses.extra<-matrix(NA,M,16)
Pars<-matrix(NA,M,17)
VarCov<-matrix(NA,M,17^2)
Pars1<-matrix(NA,M,16)
VarCov1<-matrix(NA,M,16^2)
Pars3<-matrix(NA,M,22)
VarCov3<-matrix(NA,M,22^2)
Pars4<-matrix(NA,M,19)
VarCov4<-matrix(NA,M,19^2)
for (i in 1:M) {
  d.imp<-data.frame(mi.data.frame(IMP,m=i),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m)
  #   
  #   dd<-datadist(d.imp)
  #   options(datadist="dd")
  mod<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site),data=d.imp)
  stuff1<-summary(mod,age2=c(40,20),sqrt.cd41.=c(sqrt(350),sqrt(50)),sqrt.cd42.=c(sqrt(350),sqrt(50)),year2=c(2004,2005),init.reason.cat="toxicity",
                  time.since.haart.y=c(3/12,6/12))[c("male","age2","aids.enrollment","sqrt.cd41.","sqrt.cd42.","year2","time.since.haart.y",
                                                     "init.reason.cat - failure:toxicity","init.reason.cat - other:toxicity",
                                                     "init.reason.cat - unknown:toxicity"),c(4,5)]
  stuff2<-summary(mod,age2=c(40,30),sqrt.cd41.=c(sqrt(350),sqrt(100)),sqrt.cd42.=c(sqrt(350),sqrt(100)),time.since.haart.y=c(3/12,1))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff3<-summary(mod,age2=c(40,50),sqrt.cd41.=c(sqrt(350),sqrt(200)),sqrt.cd42.=c(sqrt(350),sqrt(200)),time.since.haart.y=c(3/12,2))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff4<-summary(mod,time.since.haart.y=c(3/12,3))[c("time.since.haart.y"),c(4,5)]
  
  ans<-rbind(stuff1["male",],
             stuff1["age2",],
             stuff2["age2",],
             stuff3["age2",],
             stuff1["aids.enrollment",],
             stuff1["sqrt.cd41.",],
             stuff2["sqrt.cd41.",],
             stuff3["sqrt.cd41.",],
             stuff1["sqrt.cd42.",],
             stuff2["sqrt.cd42.",],
             stuff3["sqrt.cd42.",],
             stuff1["year2",],
             stuff1["time.since.haart.y",],
             stuff2["time.since.haart.y",],
             stuff3["time.since.haart.y",],
             stuff4,
             stuff1["init.reason.cat - failure:toxicity",],
             stuff1["init.reason.cat - other:toxicity",],
             stuff1["init.reason.cat - unknown:toxicity",])
  
  ests.primary[i,]<-ans[,1]
  ses.primary[i,]<-ans[,2]
  
  Pars[i,]<-mod$coeff
  VarCov[i,]<-matrix(mod$var,nrow=1)
  
  which.age<-which(names(mod$coeff)%in%c("age2","age2'","age2''"))
  which.cd41<-which(names(mod$coeff)%in%c("sqrt.cd41.","sqrt.cd41.'","sqrt.cd41.''"))
  which.cd42<-which(names(mod$coeff)%in%c("sqrt.cd42.","sqrt.cd42.'","sqrt.cd42.''"))
  which.tsh<-which(names(mod$coeff)%in%c("time.since.haart.y","time.since.haart.y'"))
  which.irc<-which(names(mod$coeff)%in%c("init.reason.cat=failure","init.reason.cat=other","init.reason.cat=unknown"))
  
  
  ####  Now the additional models
  
  mod1<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              num.change.cat+strat(site),data=d.imp)
  
  stuff.mod1<-summary(mod1)[c("num.change.cat - Single Drug Addition/Deletion:Single Drug Substitution",
                              "num.change.cat - Multidrug Change:Single Drug Substitution"),c(4,5)]
  
  
  mod2<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              n.change+strat(site),data=d.imp)
  stuff.mod2<-summary(mod2,n.change=c(1,2))["n.change",c(4,5)]
  
  mod3<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change+strat(site),data=d.imp)
  stuff.mod3<-summary(mod3)[c("type.change - NNRTI to NNRTI; NNRTI switched:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to NNRTI; changes in NNRTI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; NRTI(s) switched, added, or removed:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; PI switched, added, removed, boosted, or unboosted:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; changes in PI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to PI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to NNRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - Other:NNRTI to NNRTI; NRTI(s) switched, added, or removed"),c(4,5)]
  
  
  mod4<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change.m+strat(site),data=d.imp)
  stuff.mod4<-summary(mod4)[c("type.change.m - Change of NNRTI:Change of NRTI",
                              "type.change.m - Change of NRTI and NNRTI:Change of NRTI",
                              "type.change.m - Change of PI:Change of NRTI",
                              "type.change.m - Change of NRTI and PI:Change of NRTI",
                              "type.change.m - Other:Change of NRTI"),c(4,5)]
  
  
  
  ests.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,1]
  ses.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,2]
  
  
  
  Pars1[i,]<-mod1$coeff
  VarCov1[i,]<-matrix(mod1$var,nrow=1)
  
  which.tc1<-which(names(mod1$coeff)%in%c("num.change.cat=Single Drug Addition/Deletion",
                                          "num.change.cat=Multidrug Change"))
  
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc3<-which(names(mod3$coeff)%in%c("type.change=NNRTI to NNRTI; NNRTI switched",
                                          "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                                          "type.change=PI to PI; NRTI(s) switched, added, or removed",
                                          "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                                          "type.change=PI to PI; changes in PI and NRTI",
                                          "type.change=NNRTI to PI",                                             
                                          "type.change=PI to NNRTI",
                                          "type.change=Other"))
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc4<-which(names(mod4$coeff)%in%c("type.change.m=Change of NNRTI",
                                          "type.change.m=Change of NRTI and NNRTI",                   
                                          "type.change.m=Change of PI",
                                          "type.change.m=Change of NRTI and PI",
                                          "type.change.m=Other"))
  Pars4[i,]<-mod4$coeff
  VarCov4[i,]<-matrix(mod4$var,nrow=1)
  
  
}

ests<-cbind(ests.primary,ests.extra)
ses<-cbind(ses.primary,ses.extra)

log.hr<-apply(ests,2,mean)
ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
hr<-exp(log.hr)
hr.lower<-exp(log.hr-1.96*ses.log.hr)
hr.upper<-exp(log.hr+1.96*ses.log.hr)
p.val<-2*pnorm(-abs(log.hr/ses.log.hr))


mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=17,ncol=17))
mean.Pars<-apply(Pars,2,mean)
pval.age.t<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
pval.cd41.t<-1-pchisq(mean.Pars[which.cd41]%*%mi.information[which.cd41,which.cd41]%*%mean.Pars[which.cd41],length(which.cd41))
pval.cd42.t<-1-pchisq(mean.Pars[which.cd42]%*%mi.information[which.cd42,which.cd42]%*%mean.Pars[which.cd42],length(which.cd42))
pval.time.since.haart.t<-1-pchisq(mean.Pars[which.tsh]%*%mi.information[which.tsh,which.tsh]%*%mean.Pars[which.tsh],length(which.tsh))
pval.init.reason.cat.t<-1-pchisq(mean.Pars[which.irc]%*%mi.information[which.irc,which.irc]%*%mean.Pars[which.irc],length(which.irc))

mi.information1<-solve(matrix(apply(VarCov1,2,mean)+(M+1)*apply(VarCov1,2,var)/M,nrow=16,ncol=16))
mean.Pars1<-apply(Pars1,2,mean)
pval.num.change.cat.t<-1-pchisq(mean.Pars1[which.tc1]%*%mi.information1[which.tc1,which.tc1]%*%mean.Pars1[which.tc1],length(which.tc1))

mi.information3<-solve(matrix(apply(VarCov3,2,mean)+(M+1)*apply(VarCov3,2,var)/M,nrow=22,ncol=22))
mean.Pars3<-apply(Pars3,2,mean)
pval.type.change.t<-1-pchisq(mean.Pars3[which.tc3]%*%mi.information3[which.tc3,which.tc3]%*%mean.Pars3[which.tc3],length(which.tc3))

mi.information4<-solve(matrix(apply(VarCov4,2,mean)+(M+1)*apply(VarCov4,2,var)/M,nrow=19,ncol=19))
mean.Pars4<-apply(Pars4,2,mean)
pval.type.change.m.t<-1-pchisq(mean.Pars4[which.tc4]%*%mi.information4[which.tc4,which.tc4]%*%mean.Pars4[which.tc4],length(which.tc4))


hr.adj.t<-data.frame(label=c("male","age2 20:40","age2 30:40","age2 50:40","aids.enrollment",
                             "cd41 50:350","cd41 100:350","cd41 200:350","cd42 50:350","cd42 100:350","cd42 200:350",
                             "year2","time.since.haart 6:3","time.since.haart 12:3","time.since.haart 24:3","time.since.haart 36:3",
                             "init.reason.cat failure:toxicity","init.reason.cat other:toxicity","init.reason.cat unknown:toxicity",
                             "num.change.cat single drug addition","num.change.cat multidrug change",
                             "n.change",
                             "type.change=NNRTI to NNRTI; NNRTI switched",
                             "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                             "type.change=PI to PI; NRTI(s) switched, added, or removed",
                             "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                             "type.change=PI to PI; changes in PI and NRTI",
                             "type.change=NNRTI to PI",                                             
                             "type.change=PI to NNRTI",
                             "type.change=Other",
                             "type.change.m=NNRTI",
                             "type.change.m=NRTI and NNRTI",
                             "type.change.m=PI",
                             "type.change.m=NRTI and PI",
                             "type.change.m=Other"),
                     cbind(hr,hr.lower,hr.upper,p.val))


save(hr.adj.t,pval.age.t,pval.cd41.t,pval.cd42.t,pval.time.since.haart.t,pval.init.reason.cat.t,pval.num.change.cat.t,pval.type.change.t,
     pval.type.change.m.t,
     file="hr-tox-adjust.Rda")


####  Analyses with individual regimens

lhr2.est<-lhr2.ses<-matrix(NA,14,M)
lhr2A.est<-lhr2A.ses<-matrix(NA,8,M)
lhr2B.est<-lhr2B.ses<-matrix(NA,4,M)
for (i in 1:M){
  data.frame1<-data.frame(mi.data.frame(IMP,m=i),
                          r2.3tc,r2.ftc,r2.efv,r2.nvp,r2.abc,r2.azt,r2.d4t,r2.ddi,r2.tdf,r2.atv,r2.sqv,r2.nfv,r2.lpv,r2.idv,
                          second.class=d$second.class)
  dd<-datadist(data.frame1)
  options(datadist="dd")
  
  mod<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  
  mod1<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  mod2<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.3tc,data=data.frame1)
  mod3<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ftc,data=data.frame1)
  mod4<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.efv,data=data.frame1)
  mod5<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.nvp,data=data.frame1)
  mod6<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.abc,data=data.frame1)
  mod7<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.azt,data=data.frame1)
  mod8<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.d4t,data=data.frame1)
  mod9<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ddi,data=data.frame1)
  mod10<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.tdf,data=data.frame1)
  mod11<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.atv,data=data.frame1)
  mod12<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.sqv,data=data.frame1)
  mod13<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.nfv,data=data.frame1)
  mod14<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.lpv,data=data.frame1)
  mod15<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.idv,data=data.frame1)
  
  lhr2.3tc<-summary(mod2)[c(15),c(4,5)]
  lhr2.ftc<-summary(mod3)[c(15),c(4,5)]
  lhr2.efv<-summary(mod4)[c(15),c(4,5)]
  lhr2.nvp<-summary(mod5)[c(15),c(4,5)]
  lhr2.abc<-summary(mod6)[c(15),c(4,5)]
  lhr2.azt<-summary(mod7)[c(15),c(4,5)]
  lhr2.d4t<-summary(mod8)[c(15),c(4,5)]
  lhr2.ddi<-summary(mod9)[c(15),c(4,5)]
  lhr2.tdf<-summary(mod10)[c(15),c(4,5)]
  lhr2.atv<-summary(mod11)[c(15),c(4,5)]
  lhr2.sqv<-summary(mod12)[c(15),c(4,5)]  
  lhr2.nfv<-summary(mod13)[c(15),c(4,5)]
  lhr2.lpv<-summary(mod14)[c(15),c(4,5)]
  lhr2.idv<-summary(mod15)[c(15),c(4,5)]
  
  lhr2.est[,i]<-rbind(lhr2.3tc[1],lhr2.ftc[1],lhr2.efv[1],lhr2.nvp[1],lhr2.abc[1],lhr2.azt[1],
                      lhr2.d4t[1],lhr2.ddi[1],lhr2.tdf[1],lhr2.atv[1],lhr2.sqv[1],lhr2.nfv[1],lhr2.lpv[1],lhr2.idv[1])
  lhr2.ses[,i]<-rbind(lhr2.3tc[2],lhr2.ftc[2],lhr2.efv[2],lhr2.nvp[2],lhr2.abc[2],lhr2.azt[2],
                      lhr2.d4t[2],lhr2.ddi[2],lhr2.tdf[2],lhr2.atv[2],lhr2.sqv[2],lhr2.nfv[2],lhr2.lpv[2],lhr2.idv[2])
  
  mod.nnrti<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.efv,data=data.frame1, subset=(r2.efv==1|r2.nvp==1)&!(r2.efv==1&r2.nvp==1))
  mod.nrti<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                  init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi)&(r2.abc+r2.azt+r2.d4t+r2.tdf+r2.ddi==1))
  mod.nrti2<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                 subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi))
  mod.bpi<-cph(Surv(time.change2.tox,change2.tox)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                 init.reason.cat+strat(site)+r2.atv+r2.idv+r2.sqv,data=data.frame1, 
               subset=(r2.atv==1|r2.nfv==1|r2.idv==1|r2.lpv==1|r2.sqv==1)&second.class=="BOOSTED PI"&(r2.atv+r2.nfv+r2.idv+r2.lpv+r2.sqv==1))
  ####  NFV removed because of singular matrix
  
  lhr2A.efv<-summary(mod.nnrti)[c(15),c(4,5)]
  lhr2A.abc<-summary(mod.nrti)[c(15),c(4,5)]
  lhr2A.d4t<-summary(mod.nrti)[c(17),c(4,5)]
  lhr2A.ddi<-summary(mod.nrti)[c(21),c(4,5)]
  lhr2A.tdf<-summary(mod.nrti)[c(19),c(4,5)]
  lhr2B.abc<-summary(mod.nrti2)[c(15),c(4,5)]
  lhr2B.d4t<-summary(mod.nrti2)[c(17),c(4,5)]
  lhr2B.ddi<-summary(mod.nrti2)[c(21),c(4,5)]
  lhr2B.tdf<-summary(mod.nrti2)[c(19),c(4,5)]
  lhr2A.atv<-summary(mod.bpi)[c(15),c(4,5)]
  lhr2A.idv<-summary(mod.bpi)[c(17),c(4,5)]
  lhr2A.sqv<-summary(mod.bpi)[c(19),c(4,5)]  
  
  lhr2A.est[,i]<-rbind(lhr2A.efv[1],lhr2A.abc[1],lhr2A.d4t[1],lhr2A.ddi[1],lhr2A.tdf[1],lhr2A.atv[1],lhr2A.sqv[1],lhr2A.idv[1])
  lhr2A.ses[,i]<-rbind(lhr2A.efv[2],lhr2A.abc[2],lhr2A.d4t[2],lhr2A.ddi[2],lhr2A.tdf[2],lhr2A.atv[2],lhr2A.sqv[2],lhr2A.idv[2])
  
  lhr2B.est[,i]<-rbind(lhr2B.abc[1],lhr2B.d4t[1],lhr2B.ddi[1],lhr2B.tdf[1])
  lhr2B.ses[,i]<-rbind(lhr2B.abc[2],lhr2B.d4t[2],lhr2B.ddi[2],lhr2B.tdf[2])
  
  
}

log.hr.reg<-apply(lhr2.est,1,mean)
ses.log.hr.reg<-sqrt(apply(lhr2.ses^2,1,mean)+(M+1)*apply(lhr2.est,1,var)/M)
hr.reg<-exp(log.hr.reg)
hr.reg.lower<-exp(log.hr.reg-1.96*ses.log.hr.reg)
hr.reg.upper<-exp(log.hr.reg+1.96*ses.log.hr.reg)
p.val.reg<-2*pnorm(-abs(log.hr.reg/ses.log.hr.reg))

hr.tox.reg<-cbind(hr.reg,hr.reg.lower,hr.reg.upper,p.val.reg)
names.hr.tox.reg<-c("3tc","ftc","efv","nvp","abc","azt","d4t","ddi","tdf","atv","sqv","nfv","lpv","idv")


log.hr.regA<-apply(lhr2A.est,1,mean)
ses.log.hr.regA<-sqrt(apply(lhr2A.ses^2,1,mean)+(M+1)*apply(lhr2A.est,1,var)/M)
hr.regA<-exp(log.hr.regA)
hr.reg.lowerA<-exp(log.hr.regA-1.96*ses.log.hr.regA)
hr.reg.upperA<-exp(log.hr.regA+1.96*ses.log.hr.regA)
p.val.regA<-2*pnorm(-abs(log.hr.regA/ses.log.hr.regA))

hr.tox.regA<-cbind(hr.regA,hr.reg.lowerA,hr.reg.upperA,p.val.regA)
names.hr.tox.regA<-c("efv","abc","d4t","ddi","tdf","atv","sqv","idv")

log.hr.regB<-apply(lhr2B.est,1,mean)
ses.log.hr.regB<-sqrt(apply(lhr2B.ses^2,1,mean)+(M+1)*apply(lhr2B.est,1,var)/M)
hr.regB<-exp(log.hr.regB)
hr.reg.lowerB<-exp(log.hr.regB-1.96*ses.log.hr.regB)
hr.reg.upperB<-exp(log.hr.regB+1.96*ses.log.hr.regB)
p.val.regB<-2*pnorm(-abs(log.hr.regB/ses.log.hr.regB))

hr.tox.regB<-cbind(hr.regB,hr.reg.lowerB,hr.reg.upperB,p.val.regB)
names.hr.tox.regB<-c("abc","d4t","ddi","tdf")

save(hr.tox.reg,names.hr.tox.reg,hr.tox.regA,names.hr.tox.regA,hr.tox.regB,names.hr.tox.regB,file="hr-tox-reg-adj.Rda")











############  Time to change due to failure



dd<-datadist(time.change2.fail,change2.fail,site,male,age2,cd41,cd42,year2,time.since.haart.y,init.reason.cat,num.change.cat,classify.type.arv.change,aids.enrollment)
options(datadist="dd")

mod.male.tfail<-coxph(Surv(time.change2.fail,change2.fail)~male+strata(site))
mod.age.tfail<-cph(Surv(time.change2.fail,change2.fail)~rcs(age2,4)+strat(site))
mod.aids.tfail<-coxph(Surv(time.change2.fail,change2.fail)~aids.enrollment+strata(site))
mod.cd41.tfail<-cph(Surv(time.change2.fail,change2.fail)~rcs(sqrt(cd41),4)+strat(site))
mod.cd42.tfail<-cph(Surv(time.change2.fail,change2.fail)~rcs(sqrt(cd42),4)+strat(site))
mod.year2.tfail<-coxph(Surv(time.change2.fail,change2.fail)~year2+strata(site))   #removed non-linear piece
mod.lengthart1.tfail<-cph(Surv(time.change2.fail,change2.fail)~rcs(log(time.since.haart.y),3)+strat(site))
mod.initreas.tfail<-coxph(Surv(time.change2.fail,change2.fail)~init.reason.cat+strata(site))
mod.ndrugs.tfail<-coxph(Surv(time.change2.fail,change2.fail)~n.change+strata(site))
mod.ndrugscat.tfail<-coxph(Surv(time.change2.fail,change2.fail)~num.change.cat+strata(site))
mod.typechange.tfail<-coxph(Surv(time.change2.fail,change2.fail)~classify.type.arv.change+strata(site))
mod.typechange.m.tfail<-coxph(Surv(time.change2.fail,change2.fail)~classify.type.arv.change.m+strata(site))

hr.male.tf<-summary(mod.male.tfail)$conf.int[c(1,3,4)]
p.male.tf<-summary(mod.male.tfail)$logtest[3]

p.age.tf<-anova(mod.age.tfail)[3,3]
hr.age.tf<-rbind(summary(mod.age.tfail,age2=c(40,20))[2,c(4,6,7)],
                summary(mod.age.tfail,age2=c(40,30))[2,c(4,6,7)],
                summary(mod.age.tfail,age2=c(40,50))[2,c(4,6,7)])

hr.aids.tf<-summary(mod.aids.tfail)$conf.int[c(1,3,4)]
p.aids.tf<-summary(mod.aids.tfail)$logtest[3]

p.cd41.tf<-anova(mod.cd41.tfail)[3,3]
hr.cd41.tf<-rbind(summary(mod.cd41.tfail,cd41=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd41.tfail,cd41=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd41.tfail,cd41=c(350,200))[2,c(4,6,7)])

p.cd42.tf<-anova(mod.cd42.tfail)[3,3]
hr.cd42.tf<-rbind(summary(mod.cd42.tfail,cd42=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd42.tfail,cd42=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd42.tfail,cd42=c(350,200))[2,c(4,6,7)])

hr.year2.tf<-summary(mod.year2.tfail)$conf.int[c(1,3,4)]
p.year2.tf<-summary(mod.year2.tfail)$logtest[3]

p.lengthart1.tf<-anova(mod.lengthart1.tfail)[3,3]
hr.lengthart1.tf<-rbind(summary(mod.lengthart1.tfail,time.since.haart.y=c(3/12,6/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.tfail,time.since.haart.y=c(3/12,12/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.tfail,time.since.haart.y=c(3/12,2))[2,c(4,6,7)],
                       summary(mod.lengthart1.tfail,time.since.haart.y=c(3/12,3))[2,c(4,6,7)])

hr.initreas.tf<-summary(mod.initreas.tfail)$conf.int[,c(1,3,4)]
p.initreas.tf<-c(summary(mod.initreas.tfail)$logtest[3],
                summary(mod.initreas.tfail)$coeff[,5])

hr.ndrugs.tf<-summary(mod.ndrugs.tfail)$conf.int[c(1,3,4)]
p.ndrugs.tf<-summary(mod.ndrugs.tfail)$logtest[3]

hr.ndrugscat.tf<-summary(mod.ndrugscat.tfail)$conf.int[,c(1,3,4)]
p.ndrugscat.tf<-c(summary(mod.ndrugscat.tfail)$logtest[3],
                 summary(mod.ndrugscat.tfail)$coeff[,5])

hr.typechange.tf<-summary(mod.typechange.tfail)$conf.int[,c(1,3,4)]
p.typechange.tf<-c(summary(mod.typechange.tfail)$logtest[3],
                  summary(mod.typechange.tfail)$coeff[,5])

hr.typechangem.tf<-summary(mod.typechange.m.tfail)$conf.int[,c(1,3,4)]
p.typechangem.tf<-c(summary(mod.typechange.m.tfail)$logtest[3],
                   summary(mod.typechange.m.tfail)$coeff[,5])


save(hr.male.tf,hr.age.tf,hr.cd41.tf,hr.cd42.tf,hr.year2.tf,hr.lengthart1.tf,hr.initreas.tf,hr.ndrugs.tf,hr.ndrugscat.tf,hr.typechange.tf,hr.aids.tf,
     hr.typechangem.tf,
     p.male.tf, p.age.tf, p.cd41.tf, p.cd42.tf, p.year2.tf, p.lengthart1.tf, p.initreas.tf, p.ndrugs.tf, p.ndrugscat.tf, p.typechange.tf,p.aids.tf,
     p.typechangem.tf,
     file="hr-tfail-unadjust.Rda")




#### Multiple imputation for nadir CD4 at first HAART and CD4 at start of second regimen




dd<-datadist(data.frame(mi.data.frame(IMP,m=1),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m))
options(datadist="dd")
ests.primary<-ses.primary<-matrix(NA,M,19)
ests.extra<-ses.extra<-matrix(NA,M,16)
Pars<-matrix(NA,M,17)
VarCov<-matrix(NA,M,17^2)
Pars1<-matrix(NA,M,16)
VarCov1<-matrix(NA,M,16^2)
Pars3<-matrix(NA,M,22)
VarCov3<-matrix(NA,M,22^2)
Pars4<-matrix(NA,M,19)
VarCov4<-matrix(NA,M,19^2)
for (i in 1:M) {
  d.imp<-data.frame(mi.data.frame(IMP,m=i),type.change=classify.type.arv.change,type.change.m=classify.type.arv.change.m)
  #   
  #   dd<-datadist(d.imp)
  #   options(datadist="dd")
  mod<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site),data=d.imp)
  stuff1<-summary(mod,age2=c(40,20),sqrt.cd41.=c(sqrt(350),sqrt(50)),sqrt.cd42.=c(sqrt(350),sqrt(50)),year2=c(2004,2005),init.reason.cat="toxicity",
                  time.since.haart.y=c(3/12,6/12))[c("male","age2","aids.enrollment","sqrt.cd41.","sqrt.cd42.","year2","time.since.haart.y",
                                                     "init.reason.cat - failure:toxicity","init.reason.cat - other:toxicity",
                                                     "init.reason.cat - unknown:toxicity"),c(4,5)]
  stuff2<-summary(mod,age2=c(40,30),sqrt.cd41.=c(sqrt(350),sqrt(100)),sqrt.cd42.=c(sqrt(350),sqrt(100)),time.since.haart.y=c(3/12,1))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff3<-summary(mod,age2=c(40,50),sqrt.cd41.=c(sqrt(350),sqrt(200)),sqrt.cd42.=c(sqrt(350),sqrt(200)),time.since.haart.y=c(3/12,2))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff4<-summary(mod,time.since.haart.y=c(3/12,3))[c("time.since.haart.y"),c(4,5)]
  
  ans<-rbind(stuff1["male",],
             stuff1["age2",],
             stuff2["age2",],
             stuff3["age2",],
             stuff1["aids.enrollment",],
             stuff1["sqrt.cd41.",],
             stuff2["sqrt.cd41.",],
             stuff3["sqrt.cd41.",],
             stuff1["sqrt.cd42.",],
             stuff2["sqrt.cd42.",],
             stuff3["sqrt.cd42.",],
             stuff1["year2",],
             stuff1["time.since.haart.y",],
             stuff2["time.since.haart.y",],
             stuff3["time.since.haart.y",],
             stuff4,
             stuff1["init.reason.cat - failure:toxicity",],
             stuff1["init.reason.cat - other:toxicity",],
             stuff1["init.reason.cat - unknown:toxicity",])
  
  ests.primary[i,]<-ans[,1]
  ses.primary[i,]<-ans[,2]
  
  Pars[i,]<-mod$coeff
  VarCov[i,]<-matrix(mod$var,nrow=1)
  
  which.age<-which(names(mod$coeff)%in%c("age2","age2'","age2''"))
  which.cd41<-which(names(mod$coeff)%in%c("sqrt.cd41.","sqrt.cd41.'","sqrt.cd41.''"))
  which.cd42<-which(names(mod$coeff)%in%c("sqrt.cd42.","sqrt.cd42.'","sqrt.cd42.''"))
  which.tsh<-which(names(mod$coeff)%in%c("time.since.haart.y","time.since.haart.y'"))
  which.irc<-which(names(mod$coeff)%in%c("init.reason.cat=failure","init.reason.cat=other","init.reason.cat=unknown"))
  
  
  ####  Now the additional models
  
  mod1<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              num.change.cat+strat(site),data=d.imp)
  
  stuff.mod1<-summary(mod1)[c("num.change.cat - Single Drug Addition/Deletion:Single Drug Substitution",
                              "num.change.cat - Multidrug Change:Single Drug Substitution"),c(4,5)]
  
  
  mod2<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              n.change+strat(site),data=d.imp)
  stuff.mod2<-summary(mod2,n.change=c(1,2))["n.change",c(4,5)]
  
  mod3<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change+strat(site),data=d.imp)
  stuff.mod3<-summary(mod3)[c("type.change - NNRTI to NNRTI; NNRTI switched:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to NNRTI; changes in NNRTI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; NRTI(s) switched, added, or removed:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; PI switched, added, removed, boosted, or unboosted:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; changes in PI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to PI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to NNRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - Other:NNRTI to NNRTI; NRTI(s) switched, added, or removed"),c(4,5)]
  
  
  mod4<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change.m+strat(site),data=d.imp)
  stuff.mod4<-summary(mod4)[c("type.change.m - Change of NNRTI:Change of NRTI",
                              "type.change.m - Change of NRTI and NNRTI:Change of NRTI",
                              "type.change.m - Change of PI:Change of NRTI",
                              "type.change.m - Change of NRTI and PI:Change of NRTI",
                              "type.change.m - Other:Change of NRTI"),c(4,5)]
  
  
  
  ests.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,1]
  ses.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,2]
  
  
  
  Pars1[i,]<-mod1$coeff
  VarCov1[i,]<-matrix(mod1$var,nrow=1)
  
  which.tc1<-which(names(mod1$coeff)%in%c("num.change.cat=Single Drug Addition/Deletion",
                                          "num.change.cat=Multidrug Change"))
  
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc3<-which(names(mod3$coeff)%in%c("type.change=NNRTI to NNRTI; NNRTI switched",
                                          "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                                          "type.change=PI to PI; NRTI(s) switched, added, or removed",
                                          "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                                          "type.change=PI to PI; changes in PI and NRTI",
                                          "type.change=NNRTI to PI",                                             
                                          "type.change=PI to NNRTI",
                                          "type.change=Other"))
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc4<-which(names(mod4$coeff)%in%c("type.change.m=Change of NNRTI",
                                          "type.change.m=Change of NRTI and NNRTI",                   
                                          "type.change.m=Change of PI",
                                          "type.change.m=Change of NRTI and PI",
                                          "type.change.m=Other"))
  Pars4[i,]<-mod4$coeff
  VarCov4[i,]<-matrix(mod4$var,nrow=1)
  
  
}

ests<-cbind(ests.primary,ests.extra)
ses<-cbind(ses.primary,ses.extra)

log.hr<-apply(ests,2,mean)
ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
hr<-exp(log.hr)
hr.lower<-exp(log.hr-1.96*ses.log.hr)
hr.upper<-exp(log.hr+1.96*ses.log.hr)
p.val<-2*pnorm(-abs(log.hr/ses.log.hr))


mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=17,ncol=17))
mean.Pars<-apply(Pars,2,mean)
pval.age.tf<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
pval.cd41.tf<-1-pchisq(mean.Pars[which.cd41]%*%mi.information[which.cd41,which.cd41]%*%mean.Pars[which.cd41],length(which.cd41))
pval.cd42.tf<-1-pchisq(mean.Pars[which.cd42]%*%mi.information[which.cd42,which.cd42]%*%mean.Pars[which.cd42],length(which.cd42))
pval.time.since.haart.tf<-1-pchisq(mean.Pars[which.tsh]%*%mi.information[which.tsh,which.tsh]%*%mean.Pars[which.tsh],length(which.tsh))
pval.init.reason.cat.tf<-1-pchisq(mean.Pars[which.irc]%*%mi.information[which.irc,which.irc]%*%mean.Pars[which.irc],length(which.irc))

mi.information1<-solve(matrix(apply(VarCov1,2,mean)+(M+1)*apply(VarCov1,2,var)/M,nrow=16,ncol=16))
mean.Pars1<-apply(Pars1,2,mean)
pval.num.change.cat.tf<-1-pchisq(mean.Pars1[which.tc1]%*%mi.information1[which.tc1,which.tc1]%*%mean.Pars1[which.tc1],length(which.tc1))

mi.information3<-solve(matrix(apply(VarCov3,2,mean)+(M+1)*apply(VarCov3,2,var)/M,nrow=22,ncol=22))
mean.Pars3<-apply(Pars3,2,mean)
pval.type.change.tf<-1-pchisq(mean.Pars3[which.tc3]%*%mi.information3[which.tc3,which.tc3]%*%mean.Pars3[which.tc3],length(which.tc3))

mi.information4<-solve(matrix(apply(VarCov4,2,mean)+(M+1)*apply(VarCov4,2,var)/M,nrow=19,ncol=19))
mean.Pars4<-apply(Pars4,2,mean)
pval.type.change.m.tf<-1-pchisq(mean.Pars4[which.tc4]%*%mi.information4[which.tc4,which.tc4]%*%mean.Pars4[which.tc4],length(which.tc4))


hr.adj.tf<-data.frame(label=c("male","age2 20:40","age2 30:40","age2 50:40","aids.enrollment",
                             "cd41 50:350","cd41 100:350","cd41 200:350","cd42 50:350","cd42 100:350","cd42 200:350",
                             "year2","time.since.haart 6:3","time.since.haart 12:3","time.since.haart 24:3","time.since.haart 36:3",
                             "init.reason.cat failure:toxicity","init.reason.cat other:toxicity","init.reason.cat unknown:toxicity",
                             "num.change.cat single drug addition","num.change.cat multidrug change",
                             "n.change",
                             "type.change=NNRTI to NNRTI; NNRTI switched",
                             "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                             "type.change=PI to PI; NRTI(s) switched, added, or removed",
                             "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                             "type.change=PI to PI; changes in PI and NRTI",
                             "type.change=NNRTI to PI",                                             
                             "type.change=PI to NNRTI",
                             "type.change=Other",
                             "type.change.m=NNRTI",
                             "type.change.m=NRTI and NNRTI",
                             "type.change.m=PI",
                             "type.change.m=NRTI and PI",
                             "type.change.m=Other"),
                     cbind(hr,hr.lower,hr.upper,p.val))


save(hr.adj.tf,pval.age.tf,pval.cd41.tf,pval.cd42.tf,pval.time.since.haart.tf,pval.init.reason.cat.tf,pval.num.change.cat.tf,pval.type.change.tf,
     pval.type.change.m.tf,
     file="hr-tfail-adjust.Rda")


####  Analyses with individual regimens

lhr2.est<-lhr2.ses<-matrix(NA,14,M)
lhr2A.est<-lhr2A.ses<-matrix(NA,8,M)
lhr2B.est<-lhr2B.ses<-matrix(NA,4,M)
for (i in 1:M){
  data.frame1<-data.frame(mi.data.frame(IMP,m=i),
                          r2.3tc,r2.ftc,r2.efv,r2.nvp,r2.abc,r2.azt,r2.d4t,r2.ddi,r2.tdf,r2.atv,r2.sqv,r2.nfv,r2.lpv,r2.idv,
                          second.class=d$second.class)
  dd<-datadist(data.frame1)
  options(datadist="dd")
  
  mod<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  
  mod1<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  mod2<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.3tc,data=data.frame1)
  mod3<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ftc,data=data.frame1)
  mod4<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.efv,data=data.frame1)
  mod5<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.nvp,data=data.frame1)
  mod6<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.abc,data=data.frame1)
  mod7<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.azt,data=data.frame1)
  mod8<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.d4t,data=data.frame1)
  mod9<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ddi,data=data.frame1)
  mod10<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.tdf,data=data.frame1)
  mod11<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.atv,data=data.frame1)
  mod12<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.sqv,data=data.frame1)
  mod13<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.nfv,data=data.frame1)
  mod14<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.lpv,data=data.frame1)
  mod15<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.idv,data=data.frame1)
  
  lhr2.3tc<-summary(mod2)[c(15),c(4,5)]
  lhr2.ftc<-summary(mod3)[c(15),c(4,5)]
  lhr2.efv<-summary(mod4)[c(15),c(4,5)]
  lhr2.nvp<-summary(mod5)[c(15),c(4,5)]
  lhr2.abc<-summary(mod6)[c(15),c(4,5)]
  lhr2.azt<-summary(mod7)[c(15),c(4,5)]
  lhr2.d4t<-summary(mod8)[c(15),c(4,5)]
  lhr2.ddi<-summary(mod9)[c(15),c(4,5)]
  lhr2.tdf<-summary(mod10)[c(15),c(4,5)]
  lhr2.atv<-summary(mod11)[c(15),c(4,5)]
  lhr2.sqv<-summary(mod12)[c(15),c(4,5)]  
  lhr2.nfv<-summary(mod13)[c(15),c(4,5)]
  lhr2.lpv<-summary(mod14)[c(15),c(4,5)]
  lhr2.idv<-summary(mod15)[c(15),c(4,5)]
  
  lhr2.est[,i]<-rbind(lhr2.3tc[1],lhr2.ftc[1],lhr2.efv[1],lhr2.nvp[1],lhr2.abc[1],lhr2.azt[1],
                      lhr2.d4t[1],lhr2.ddi[1],lhr2.tdf[1],lhr2.atv[1],lhr2.sqv[1],lhr2.nfv[1],lhr2.lpv[1],lhr2.idv[1])
  lhr2.ses[,i]<-rbind(lhr2.3tc[2],lhr2.ftc[2],lhr2.efv[2],lhr2.nvp[2],lhr2.abc[2],lhr2.azt[2],
                      lhr2.d4t[2],lhr2.ddi[2],lhr2.tdf[2],lhr2.atv[2],lhr2.sqv[2],lhr2.nfv[2],lhr2.lpv[2],lhr2.idv[2])
  
  
  mod.nnrti<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.efv,data=data.frame1, subset=(r2.efv==1|r2.nvp==1)&!(r2.efv==1&r2.nvp==1))
  mod.nrti<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                  init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi)&(r2.abc+r2.azt+r2.d4t+r2.tdf+r2.ddi==1))
  mod.nrti2<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                 subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi))
  mod.bpi<-cph(Surv(time.change2.fail,change2.fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                 init.reason.cat+strat(site)+r2.atv+r2.idv+r2.sqv,data=data.frame1, 
               subset=(r2.atv==1|r2.nfv==1|r2.idv==1|r2.lpv==1|r2.sqv==1)&second.class=="BOOSTED PI"&(r2.atv+r2.nfv+r2.idv+r2.lpv+r2.sqv==1))
  ####  NFV removed because of singular matrix
  
  lhr2A.efv<-summary(mod.nnrti)[c(15),c(4,5)]
  lhr2A.abc<-summary(mod.nrti)[c(15),c(4,5)]
  lhr2A.d4t<-summary(mod.nrti)[c(17),c(4,5)]
  lhr2A.ddi<-summary(mod.nrti)[c(21),c(4,5)]
  lhr2A.tdf<-summary(mod.nrti)[c(19),c(4,5)]
  lhr2B.abc<-summary(mod.nrti2)[c(15),c(4,5)]
  lhr2B.d4t<-summary(mod.nrti2)[c(17),c(4,5)]
  lhr2B.ddi<-summary(mod.nrti2)[c(21),c(4,5)]
  lhr2B.tdf<-summary(mod.nrti2)[c(19),c(4,5)]
  lhr2A.atv<-summary(mod.bpi)[c(15),c(4,5)]
  lhr2A.idv<-summary(mod.bpi)[c(17),c(4,5)]
  lhr2A.sqv<-summary(mod.bpi)[c(19),c(4,5)]  
  
  lhr2A.est[,i]<-rbind(lhr2A.efv[1],lhr2A.abc[1],lhr2A.d4t[1],lhr2A.ddi[1],lhr2A.tdf[1],lhr2A.atv[1],lhr2A.sqv[1],lhr2A.idv[1])
  lhr2A.ses[,i]<-rbind(lhr2A.efv[2],lhr2A.abc[2],lhr2A.d4t[2],lhr2A.ddi[2],lhr2A.tdf[2],lhr2A.atv[2],lhr2A.sqv[2],lhr2A.idv[2])
  
  lhr2B.est[,i]<-rbind(lhr2B.abc[1],lhr2B.d4t[1],lhr2B.ddi[1],lhr2B.tdf[1])
  lhr2B.ses[,i]<-rbind(lhr2B.abc[2],lhr2B.d4t[2],lhr2B.ddi[2],lhr2B.tdf[2])
  
  
  
}

log.hr.reg<-apply(lhr2.est,1,mean)
ses.log.hr.reg<-sqrt(apply(lhr2.ses^2,1,mean)+(M+1)*apply(lhr2.est,1,var)/M)
hr.reg<-exp(log.hr.reg)
hr.reg.lower<-exp(log.hr.reg-1.96*ses.log.hr.reg)
hr.reg.upper<-exp(log.hr.reg+1.96*ses.log.hr.reg)
p.val.reg<-2*pnorm(-abs(log.hr.reg/ses.log.hr.reg))

hr.tfail.reg<-cbind(hr.reg,hr.reg.lower,hr.reg.upper,p.val.reg)
names.hr.tfail.reg<-c("3tc","ftc","efv","nvp","abc","azt","d4t","ddi","tdf","atv","sqv","nfv","lpv","idv")


log.hr.regA<-apply(lhr2A.est,1,mean)
ses.log.hr.regA<-sqrt(apply(lhr2A.ses^2,1,mean)+(M+1)*apply(lhr2A.est,1,var)/M)
hr.regA<-exp(log.hr.regA)
hr.reg.lowerA<-exp(log.hr.regA-1.96*ses.log.hr.regA)
hr.reg.upperA<-exp(log.hr.regA+1.96*ses.log.hr.regA)
p.val.regA<-2*pnorm(-abs(log.hr.regA/ses.log.hr.regA))

hr.tfail.regA<-cbind(hr.regA,hr.reg.lowerA,hr.reg.upperA,p.val.regA)
names.hr.tfail.regA<-c("efv","abc","d4t","ddi","tdf","atv","sqv","idv")

log.hr.regB<-apply(lhr2B.est,1,mean)
ses.log.hr.regB<-sqrt(apply(lhr2B.ses^2,1,mean)+(M+1)*apply(lhr2B.est,1,var)/M)
hr.regB<-exp(log.hr.regB)
hr.reg.lowerB<-exp(log.hr.regB-1.96*ses.log.hr.regB)
hr.reg.upperB<-exp(log.hr.regB+1.96*ses.log.hr.regB)
p.val.regB<-2*pnorm(-abs(log.hr.regB/ses.log.hr.regB))

hr.tfail.regB<-cbind(hr.regB,hr.reg.lowerB,hr.reg.upperB,p.val.regB)
names.hr.tfail.regB<-c("abc","d4t","ddi","tdf")

save(hr.tfail.reg,names.hr.tfail.reg,hr.tfail.regA,names.hr.tfail.regA,hr.tfail.regB,names.hr.tfail.regB,file="hr-tfail-reg-adj.Rda")















#############  Time to virologic failure



rm(list=ls())

load("marcelo-third-chunk.Rda")

d<-d.new


d<-within(d,{
  init.reason.cat<-factor(init.reason.cat,levels=c("toxicity","failure","other","unknown"))
  site<-as.factor(site)
})



d<-d[which(d$time>0&!is.na(d$fail)),]

#### Univariate analyses

d$male<-as.numeric(d$male)

time<-d$time
death1<-d$death1
site<-d$site
male<-d$male
age2<-d$age2
cd41<-d$nadir.cd4.prehaart
cd42<-d$cd4.reg2
year2<-d$year.second
time.since.haart.y<-d$time.since.haart/365.25
init.reason.cat<-d$init.reason.cat
n.change<-d$n.change
num.change.cat<-factor(d$num.change.cat,levels=c("Single Drug Substitution","Multidrug Change","Single Drug Addition/Deletion"))
classify.type.arv.change<-d$classify.type.arv.change
classify.type.arv.change.m<-d$classify.type.arv.change.m
time.change2<-d$time.change2
fail<-d$fail.1000
time.failure<-d$time.failure.1000
time.fail<-ifelse(fail,time.failure,time.change2)
aids.enrollment<-ifelse(d$aids.enrollment=="Unknown",NA,ifelse(d$aids.enrollment=="AIDS",1,0))
cd4.change<-cd42-cd41

library(rms)
dd<-datadist(time.fail,fail,site,male,age2,cd41,cd42,year2,time.since.haart.y,init.reason.cat,num.change.cat,classify.type.arv.change,
             classify.type.arv.change,aids.enrollment,cd4.change)
options(datadist="dd")

mod.male.fail<-coxph(Surv(time.fail,fail)~male+strata(site))
mod.age.fail<-cph(Surv(time.fail,fail)~rcs(age2,4)+strat(site))
mod.aids.fail<-coxph(Surv(time.fail,fail)~aids.enrollment+strata(site))
mod.cd41.fail<-cph(Surv(time.fail,fail)~rcs(sqrt(cd41),4)+strat(site))
mod.cd42.fail<-cph(Surv(time.fail,fail)~rcs(sqrt(cd42),4)+strat(site))
mod.cd4.change.fail<-cph(Surv(time.fail,fail)~rcs(cd4.change,4)+strat(site))
mod.year2.fail<-coxph(Surv(time.fail,fail)~year2+strata(site))   #removed non-linear piece
mod.lengthart1.fail<-cph(Surv(time.fail,fail)~rcs(log(time.since.haart.y),3)+strat(site))
mod.initreas.fail<-coxph(Surv(time.fail,fail)~init.reason.cat+strata(site))
mod.ndrugs.fail<-coxph(Surv(time.fail,fail)~n.change+strata(site))
mod.ndrugscat.fail<-coxph(Surv(time.fail,fail)~num.change.cat+strata(site))
mod.typechange.fail<-coxph(Surv(time.fail,fail)~classify.type.arv.change+strata(site))
mod.typechange.m.fail<-coxph(Surv(time.fail,fail)~classify.type.arv.change.m+strata(site))


hr.male.f<-summary(mod.male.fail)$conf.int[c(1,3,4)]
p.male.f<-summary(mod.male.fail)$logtest[3]

p.age.f<-anova(mod.age.fail)[3,3]
hr.age.f<-rbind(summary(mod.age.fail,age2=c(40,20))[2,c(4,6,7)],
                summary(mod.age.fail,age2=c(40,30))[2,c(4,6,7)],
                summary(mod.age.fail,age2=c(40,50))[2,c(4,6,7)])

hr.aids.f<-summary(mod.aids.fail)$conf.int[c(1,3,4)]
p.aids.f<-summary(mod.aids.fail)$logtest[3]

p.cd41.f<-anova(mod.cd41.fail)[3,3]
hr.cd41.f<-rbind(summary(mod.cd41.fail,cd41=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd41.fail,cd41=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd41.fail,cd41=c(350,200))[2,c(4,6,7)])

p.cd42.f<-anova(mod.cd42.fail)[3,3]
hr.cd42.f<-rbind(summary(mod.cd42.fail,cd42=c(350,50))[2,c(4,6,7)],
                 summary(mod.cd42.fail,cd42=c(350,100))[2,c(4,6,7)],
                 summary(mod.cd42.fail,cd42=c(350,200))[2,c(4,6,7)])

quantile(cd4.change,c(.05,c(1:9)/10),na.rm=TRUE)
round(mean(cd4.change<0,na.rm=TRUE)*100,1)


p.cd4.change.f<-anova(mod.cd4.change.fail)[3,3]
hr.cd4.change.f<-rbind(summary(mod.cd4.change.fail,cd4.change=c(0,-50))[2,c(4,6,7)],
                 summary(mod.cd4.change.fail,cd4.change=c(0,50))[2,c(4,6,7)],
                 summary(mod.cd4.change.fail,cd4.change=c(0,100))[2,c(4,6,7)],
                 summary(mod.cd4.change.fail,cd4.change=c(0,200))[2,c(4,6,7)],
                 summary(mod.cd4.change.fail,cd4.change=c(0,300))[2,c(4,6,7)])

hr.year2.f<-summary(mod.year2.fail)$conf.int[c(1,3,4)]
p.year2.f<-summary(mod.year2.fail)$logtest[3]

p.lengthart1.f<-anova(mod.lengthart1.fail)[3,3]
hr.lengthart1.f<-rbind(summary(mod.lengthart1.fail,time.since.haart.y=c(3/12,6/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.fail,time.since.haart.y=c(3/12,12/12))[2,c(4,6,7)],
                       summary(mod.lengthart1.fail,time.since.haart.y=c(3/12,2))[2,c(4,6,7)],
                       summary(mod.lengthart1.fail,time.since.haart.y=c(3/12,3))[2,c(4,6,7)])

hr.initreas.f<-summary(mod.initreas.fail)$conf.int[,c(1,3,4)]
p.initreas.f<-c(summary(mod.initreas.fail)$logtest[3],
                summary(mod.initreas.fail)$coeff[,5])

hr.ndrugs.f<-summary(mod.ndrugs.fail)$conf.int[c(1,3,4)]
p.ndrugs.f<-summary(mod.ndrugs.fail)$logtest[3]

hr.ndrugscat.f<-summary(mod.ndrugscat.fail)$conf.int[,c(1,3,4)]
p.ndrugscat.f<-c(summary(mod.ndrugscat.fail)$logtest[3],
                 summary(mod.ndrugscat.fail)$coeff[,5])

hr.typechange.f<-summary(mod.typechange.fail)$conf.int[,c(1,3,4)]
p.typechange.f<-c(summary(mod.typechange.fail)$logtest[3],
                  summary(mod.typechange.fail)$coeff[,5])

hr.typechangem.f<-summary(mod.typechange.m.fail)$conf.int[,c(1,3,4)]
p.typechangem.f<-c(summary(mod.typechange.m.fail)$logtest[3],
                   summary(mod.typechange.m.fail)$coeff[,5])


save(hr.male.f,hr.age.f,hr.cd41.f,hr.cd42.f,hr.year2.f,hr.lengthart1.f,hr.initreas.f,hr.ndrugs.f,hr.ndrugscat.f,hr.typechange.f,hr.aids.f,
     hr.typechangem.f, hr.cd4.change.f,
     p.male.f, p.age.f, p.cd41.f, p.cd42.f, p.year2.f, p.lengthart1.f, p.initreas.f, p.ndrugs.f, p.ndrugscat.f, p.typechange.f,p.aids.f,
     p.typechangem.f, p.cd4.change.f, cd4.change,
     file="hr-fail-unadjust.Rda")




#### Multiple imputation for nadir CD4 at first HAART and CD4 at start of second regimen


dd<-datadist(time.fail,fail,site,male,age2,cd41,cd42,year2,time.since.haart.y,init.reason.cat,num.change.cat,
             classify.type.arv.change,classify.type.arv.change.m,aids.enrollment)
options(datadist="dd")

d.analysis<-data.frame(male,age2,sqrt(cd41),sqrt(cd42),year2,time.since.haart.y,init.reason.cat,num.change.cat,n.change,site,
                       log(time.fail),fail,log(time.fail)*fail,aids.enrollment)
# didn't include classify.type.arv into imputation model

M<-10
IMP<-mi(d.analysis,n.imp=M,seed=20130131)     # The actual imputation


dd<-datadist(data.frame(mi.data.frame(IMP,m=1),type.change=classify.type.arv.change,
                        type.change.m=classify.type.arv.change.m,
                        cd4.change=mi.data.frame(IMP,m=1)$sqrt.cd42.^2-mi.data.frame(IMP,m=1)$sqrt.cd41.^2))
options(datadist="dd")
ests.primary<-ses.primary<-matrix(NA,M,19)
ests.extra<-ses.extra<-matrix(NA,M,16)
ests.delta.cd4<-ses.delta.cd4<-matrix(NA,M,20)
Pars<-matrix(NA,M,17)
VarCov<-matrix(NA,M,17^2)
Pars1<-matrix(NA,M,16)
VarCov1<-matrix(NA,M,16^2)
Pars3<-matrix(NA,M,22)
VarCov3<-matrix(NA,M,22^2)
Pars4<-matrix(NA,M,19)
VarCov4<-matrix(NA,M,19^2)
Pars5<-matrix(NA,M,17)
VarCov5<-matrix(NA,M,17^2)
for (i in 1:M) {
  d.imp<-data.frame(mi.data.frame(IMP,m=i),type.change=classify.type.arv.change,
                    type.change.m=classify.type.arv.change.m,
                    cd4.change=mi.data.frame(IMP,m=i)$sqrt.cd42.^2-mi.data.frame(IMP,m=i)$sqrt.cd41.^2)
  #   
  #   dd<-datadist(d.imp)
  #   options(datadist="dd")
  mod<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site),data=d.imp, x=T, y=T, surv=T)
  
  #phtest<-cox.zph(mod, transform='log')    ##  No significant violation of PH
  
  stuff1<-summary(mod,age2=c(40,20),sqrt.cd41.=c(sqrt(350),sqrt(50)),sqrt.cd42.=c(sqrt(350),sqrt(50)),year2=c(2004,2005),init.reason.cat="toxicity",
                  time.since.haart.y=c(3/12,6/12))[c("male","age2","aids.enrollment","sqrt.cd41.","sqrt.cd42.","year2","time.since.haart.y",
                                                     "init.reason.cat - failure:toxicity","init.reason.cat - other:toxicity",
                                                     "init.reason.cat - unknown:toxicity"),c(4,5)]
  stuff2<-summary(mod,age2=c(40,30),sqrt.cd41.=c(sqrt(350),sqrt(100)),sqrt.cd42.=c(sqrt(350),sqrt(100)),time.since.haart.y=c(3/12,1))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff3<-summary(mod,age2=c(40,50),sqrt.cd41.=c(sqrt(350),sqrt(200)),sqrt.cd42.=c(sqrt(350),sqrt(200)),time.since.haart.y=c(3/12,2))[
    c("age2","sqrt.cd41.","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff4<-summary(mod,time.since.haart.y=c(3/12,3))[c("time.since.haart.y"),c(4,5)]
  
  ans<-rbind(stuff1["male",],
             stuff1["age2",],
             stuff2["age2",],
             stuff3["age2",],
             stuff1["aids.enrollment",],
             stuff1["sqrt.cd41.",],
             stuff2["sqrt.cd41.",],
             stuff3["sqrt.cd41.",],
             stuff1["sqrt.cd42.",],
             stuff2["sqrt.cd42.",],
             stuff3["sqrt.cd42.",],
             stuff1["year2",],
             stuff1["time.since.haart.y",],
             stuff2["time.since.haart.y",],
             stuff3["time.since.haart.y",],
             stuff4,
             stuff1["init.reason.cat - failure:toxicity",],
             stuff1["init.reason.cat - other:toxicity",],
             stuff1["init.reason.cat - unknown:toxicity",])
  
  ests.primary[i,]<-ans[,1]
  ses.primary[i,]<-ans[,2]
  
  Pars[i,]<-mod$coeff
  VarCov[i,]<-matrix(mod$var,nrow=1)
  
  which.age<-which(names(mod$coeff)%in%c("age2","age2'","age2''"))
  which.cd41<-which(names(mod$coeff)%in%c("sqrt.cd41.","sqrt.cd41.'","sqrt.cd41.''"))
  which.cd42<-which(names(mod$coeff)%in%c("sqrt.cd42.","sqrt.cd42.'","sqrt.cd42.''"))
  which.tsh<-which(names(mod$coeff)%in%c("time.since.haart.y","time.since.haart.y'"))
  which.irc<-which(names(mod$coeff)%in%c("init.reason.cat=failure","init.reason.cat=other","init.reason.cat=unknown"))
  
  
  ####  Now the additional models
  
  mod1<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              num.change.cat+strat(site),data=d.imp)
  
  stuff.mod1<-summary(mod1)[c("num.change.cat - Single Drug Addition/Deletion:Single Drug Substitution",
                              "num.change.cat - Multidrug Change:Single Drug Substitution"),c(4,5)]
  
  
  mod2<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              n.change+strat(site),data=d.imp)
  stuff.mod2<-summary(mod2,n.change=c(1,2))["n.change",c(4,5)]
  
  mod3<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change+strat(site),data=d.imp)
  stuff.mod3<-summary(mod3)[c("type.change - NNRTI to NNRTI; NNRTI switched:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to NNRTI; changes in NNRTI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; NRTI(s) switched, added, or removed:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; PI switched, added, removed, boosted, or unboosted:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to PI; changes in PI and NRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - NNRTI to PI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - PI to NNRTI:NNRTI to NNRTI; NRTI(s) switched, added, or removed",
                              "type.change - Other:NNRTI to NNRTI; NRTI(s) switched, added, or removed"),c(4,5)]
  
  
  mod4<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              type.change.m+strat(site),data=d.imp)
  stuff.mod4<-summary(mod4)[c("type.change.m - Change of NNRTI:Change of NRTI",
                              "type.change.m - Change of NRTI and NNRTI:Change of NRTI",
                              "type.change.m - Change of PI:Change of NRTI",
                              "type.change.m - Change of NRTI and PI:Change of NRTI",
                              "type.change.m - Other:Change of NRTI"),c(4,5)]
  
  
  
  #####  New stuff added  
  mod.cd4.change<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(cd4.change,4)+
                        rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                        init.reason.cat+strat(site),data=d.imp)
  
  stuff1<-summary(mod.cd4.change,age2=c(40,20),cd4.change=c(0,-50),sqrt.cd42.=c(sqrt(350),sqrt(50)),year2=c(2004,2005),init.reason.cat="toxicity",
                  time.since.haart.y=c(3/12,6/12))[c("male","age2","aids.enrollment","cd4.change","sqrt.cd42.","year2","time.since.haart.y",
                                                     "init.reason.cat - failure:toxicity","init.reason.cat - other:toxicity",
                                                     "init.reason.cat - unknown:toxicity"),c(4,5)]
  stuff2<-summary(mod.cd4.change,age2=c(40,30),cd4.change=c(0,100),sqrt.cd42.=c(sqrt(350),sqrt(100)),time.since.haart.y=c(3/12,1))[
    c("age2","cd4.change","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff3<-summary(mod.cd4.change,age2=c(40,50),cd4.change=c(0,200),sqrt.cd42.=c(sqrt(350),sqrt(200)),time.since.haart.y=c(3/12,2))[
    c("age2","cd4.change","sqrt.cd42.","time.since.haart.y"),c(4,5)]
  stuff4<-summary(mod.cd4.change,cd4.change=c(0,300),time.since.haart.y=c(3/12,3))[c("cd4.change","time.since.haart.y"),c(4,5)]
  
  ans.delta.cd4<-rbind(stuff1["male",],
                       stuff1["age2",],
                       stuff2["age2",],
                       stuff3["age2",],
                       stuff1["aids.enrollment",],
                       stuff1["cd4.change",],
                       stuff2["cd4.change",],
                       stuff3["cd4.change",],
                       stuff4["cd4.change",],
                       stuff1["sqrt.cd42.",],
                       stuff2["sqrt.cd42.",],
                       stuff3["sqrt.cd42.",],
                       stuff1["year2",],
                       stuff1["time.since.haart.y",],
                       stuff2["time.since.haart.y",],
                       stuff3["time.since.haart.y",],
                       stuff4["time.since.haart.y",],
                       stuff1["init.reason.cat - failure:toxicity",],
                       stuff1["init.reason.cat - other:toxicity",],
                       stuff1["init.reason.cat - unknown:toxicity",])
  
  ests.delta.cd4[i,]<-ans.delta.cd4[,1]
  ses.delta.cd4[i,]<-ans.delta.cd4[,2]
  
  which1.age<-which(names(mod.cd4.change$coeff)%in%c("age2","age2'","age2''"))
  which1.delta.cd4<-which(names(mod.cd4.change$coeff)%in%c("cd4.change","cd4.change'","cd4.change''"))
  which1.cd42<-which(names(mod.cd4.change$coeff)%in%c("sqrt.cd42.","sqrt.cd42.'","sqrt.cd42.''"))
  which1.tsh<-which(names(mod.cd4.change$coeff)%in%c("time.since.haart.y","time.since.haart.y'"))
  which1.irc<-which(names(mod.cd4.change$coeff)%in%c("init.reason.cat=failure","init.reason.cat=other","init.reason.cat=unknown"))
  
  Pars5[i,]<-mod.cd4.change$coeff
  VarCov5[i,]<-matrix(mod.cd4.change$var,nrow=1)

  
  ests.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,1]
  ses.extra[i,]<-rbind(stuff.mod1,stuff.mod2,stuff.mod3,stuff.mod4)[,2]
  
  
  Pars1[i,]<-mod1$coeff
  VarCov1[i,]<-matrix(mod1$var,nrow=1)
  
  which.tc1<-which(names(mod1$coeff)%in%c("num.change.cat=Single Drug Addition/Deletion",
                                          "num.change.cat=Multidrug Change"))
  
  
  Pars3[i,]<-mod3$coeff
  VarCov3[i,]<-matrix(mod3$var,nrow=1)
  
  which.tc3<-which(names(mod3$coeff)%in%c("type.change=NNRTI to NNRTI; NNRTI switched",
                                          "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                                          "type.change=PI to PI; NRTI(s) switched, added, or removed",
                                          "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                                          "type.change=PI to PI; changes in PI and NRTI",
                                          "type.change=NNRTI to PI",                                             
                                          "type.change=PI to NNRTI",
                                          "type.change=Other"))
  
  
  which.tc4<-which(names(mod4$coeff)%in%c("type.change.m=Change of NNRTI",
                                          "type.change.m=Change of NRTI and NNRTI",                   
                                          "type.change.m=Change of PI",
                                          "type.change.m=Change of NRTI and PI",
                                          "type.change.m=Other"))
  Pars4[i,]<-mod4$coeff
  VarCov4[i,]<-matrix(mod4$var,nrow=1)
  
  
}

ests<-cbind(ests.primary,ests.extra,ests.delta.cd4)
ses<-cbind(ses.primary,ses.extra,ses.delta.cd4)

log.hr<-apply(ests,2,mean)
ses.log.hr<-sqrt(apply(ses^2,2,mean)+(M+1)*apply(ests,2,var)/M)
hr<-exp(log.hr)
hr.lower<-exp(log.hr-1.96*ses.log.hr)
hr.upper<-exp(log.hr+1.96*ses.log.hr)
p.val<-2*pnorm(-abs(log.hr/ses.log.hr))


mi.information<-solve(matrix(apply(VarCov,2,mean)+(M+1)*apply(VarCov,2,var)/M,nrow=17,ncol=17))
mean.Pars<-apply(Pars,2,mean)
pval.age.f<-1-pchisq(mean.Pars[which.age]%*%mi.information[which.age,which.age]%*%mean.Pars[which.age],length(which.age))
pval.cd41.f<-1-pchisq(mean.Pars[which.cd41]%*%mi.information[which.cd41,which.cd41]%*%mean.Pars[which.cd41],length(which.cd41))
pval.cd42.f<-1-pchisq(mean.Pars[which.cd42]%*%mi.information[which.cd42,which.cd42]%*%mean.Pars[which.cd42],length(which.cd42))
pval.time.since.haart.f<-1-pchisq(mean.Pars[which.tsh]%*%mi.information[which.tsh,which.tsh]%*%mean.Pars[which.tsh],length(which.tsh))
pval.init.reason.cat.f<-1-pchisq(mean.Pars[which.irc]%*%mi.information[which.irc,which.irc]%*%mean.Pars[which.irc],length(which.irc))

mi.information1<-solve(matrix(apply(VarCov1,2,mean)+(M+1)*apply(VarCov1,2,var)/M,nrow=16,ncol=16))
mean.Pars1<-apply(Pars1,2,mean)
pval.num.change.cat.f<-1-pchisq(mean.Pars1[which.tc1]%*%mi.information1[which.tc1,which.tc1]%*%mean.Pars1[which.tc1],length(which.tc1))

mi.information3<-solve(matrix(apply(VarCov3,2,mean)+(M+1)*apply(VarCov3,2,var)/M,nrow=22,ncol=22))
mean.Pars3<-apply(Pars3,2,mean)
pval.type.change.f<-1-pchisq(mean.Pars3[which.tc3]%*%mi.information3[which.tc3,which.tc3]%*%mean.Pars3[which.tc3],length(which.tc3))

mi.information4<-solve(matrix(apply(VarCov4,2,mean)+(M+1)*apply(VarCov4,2,var)/M,nrow=19,ncol=19))
mean.Pars4<-apply(Pars4,2,mean)
pval.type.change.m.f<-1-pchisq(mean.Pars4[which.tc4]%*%mi.information4[which.tc4,which.tc4]%*%mean.Pars4[which.tc4],length(which.tc4))

mi.information5<-solve(matrix(apply(VarCov5,2,mean)+(M+1)*apply(VarCov5,2,var)/M,nrow=17,ncol=17))
mean.Pars5<-apply(Pars5,2,mean)
pval.age.f5<-1-pchisq(mean.Pars5[which1.age]%*%mi.information5[which1.age,which1.age]%*%mean.Pars5[which1.age],length(which1.age))
pval.delta.cd4.f5<-1-pchisq(mean.Pars5[which1.delta.cd4]%*%mi.information5[which1.delta.cd4,which1.delta.cd4]%*%mean.Pars5[which1.delta.cd4],length(which1.delta.cd4))
pval.cd42.f5<-1-pchisq(mean.Pars5[which1.cd42]%*%mi.information5[which1.cd42,which1.cd42]%*%mean.Pars5[which1.cd42],length(which1.cd42))
pval.time.since.haart.f5<-1-pchisq(mean.Pars5[which1.tsh]%*%mi.information5[which1.tsh,which1.tsh]%*%mean.Pars5[which1.tsh],length(which1.tsh))
pval.init.reason.cat.f5<-1-pchisq(mean.Pars5[which1.irc]%*%mi.information5[which1.irc,which1.irc]%*%mean.Pars5[which1.irc],length(which1.irc))


hr.adj.f<-data.frame(label=c("male","age2 20:40","age2 30:40","age2 50:40","aids.enrollment",
                             "cd41 50:350","cd41 100:350","cd41 200:350","cd42 50:350","cd42 100:350","cd42 200:350",
                             "year2","time.since.haart 6:3","time.since.haart 12:3","time.since.haart 24:3","time.since.haart 36:3",
                             "init.reason.cat failure:toxicity","init.reason.cat other:toxicity","init.reason.cat unknown:toxicity",
                             "num.change.cat single drug addition","num.change.cat multidrug change",
                             "n.change",
                             "type.change=NNRTI to NNRTI; NNRTI switched",
                             "type.change=NNRTI to NNRTI; changes in NNRTI and NRTI",                   
                             "type.change=PI to PI; NRTI(s) switched, added, or removed",
                             "type.change=PI to PI; PI switched, added, removed, boosted, or unboosted",
                             "type.change=PI to PI; changes in PI and NRTI",
                             "type.change=NNRTI to PI",                                             
                             "type.change=PI to NNRTI",
                             "type.change=Other",
                             "type.change.m=NNRTI",
                             "type.change.m=NRTI and NNRTI",
                             "type.change.m=PI",
                             "type.change.m=NRTI and PI",
                             "type.change.m=Other",
                             "male mod.delta.cd4","age2 20:40 mod.delta.cd4","age2 30:40 mod.delta.cd4","age2 50:40 mod.delta.cd4",
                             "aids.enrollment mod.delta.cd4",
                             "cd4.change -50:0 mod.delta.cd4","cd4.change 100:0 mod.delta.cd4","cd4.change 200:0 mod.delta.cd4","cd4.change 300:0 mod.delta.cd4",
                             "cd42 50:350 mod.delta.cd4","cd42 100:350 mod.delta.cd4","cd42 200:350 mod.delta.cd4",
                             "year2 mod.delta.cd4","time.since.haart 6:3 mod.delta.cd4","time.since.haart 12:3 mod.delta.cd4",
                             "time.since.haart 24:3 mod.delta.cd4","time.since.haart 36:3 mod.delta.cd4",
                             "init.reason.cat failure:toxicity mod.delta.cd4","init.reason.cat other:toxicity mod.delta.cd4",
                             "init.reason.cat unknown:toxicity mod.delta.cd4"),
                     cbind(hr,hr.lower,hr.upper,p.val))

save(hr.adj.f,pval.age.f,pval.cd41.f,pval.cd42.f,pval.time.since.haart.f,pval.init.reason.cat.f,pval.num.change.cat.f,pval.type.change.f,
     pval.type.change.m.f,pval.age.f5,pval.delta.cd4.f5,pval.cd42.f5,pval.time.since.haart.f5,pval.init.reason.cat.f5,
     file="hr-fail-adjust.Rda")


####  Analyses with individual regimens

r2.3tc<-d$r2.3tc
r2.ftc<-d$r2.ftc
r2.efv<-d$r2.efv
r2.nvp<-d$r2.nvp
r2.abc<-d$r2.abc
r2.azt<-d$r2.azt
r2.d4t<-d$r2.d4t
r2.ddi<-d$r2.ddi
r2.tdf<-d$r2.tdf
r2.atv<-d$r2.atv
r2.sqv<-d$r2.sqv
r2.nfv<-d$r2.nfv
r2.lpv<-d$r2.lpv
r2.idv<-d$r2.idv

lhr2.est<-lhr2.ses<-matrix(NA,14,M)
lhr2A.est<-lhr2A.ses<-matrix(NA,8,M)
lhr2B.est<-lhr2B.ses<-matrix(NA,4,M)
for (i in 1:M){
  data.frame1<-data.frame(mi.data.frame(IMP,m=i),
                          r2.3tc,r2.ftc,r2.efv,r2.nvp,r2.abc,r2.azt,r2.d4t,r2.ddi,r2.tdf,r2.atv,r2.sqv,r2.nfv,r2.lpv,r2.idv,
                          second.class=d$second.class)
  dd<-datadist(data.frame1)
  options(datadist="dd")
  
  mod<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
             init.reason.cat+strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  
  mod1<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              strat(site)+r2.3tc+r2.ftc+r2.efv+r2.nvp+r2.abc+r2.azt+r2.d4t+r2.ddi+r2.tdf+r2.atv+r2.sqv+r2.nfv+r2.lpv+r2.idv,data=data.frame1)
  mod2<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.3tc,data=data.frame1)
  mod3<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ftc,data=data.frame1)
  mod4<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.efv,data=data.frame1)
  mod5<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.nvp,data=data.frame1)
  mod6<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.abc,data=data.frame1)
  mod7<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.azt,data=data.frame1)
  mod8<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.d4t,data=data.frame1)
  mod9<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
              init.reason.cat+strat(site)+r2.ddi,data=data.frame1)
  mod10<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.tdf,data=data.frame1)
  mod11<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.atv,data=data.frame1)
  mod12<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.sqv,data=data.frame1)
  mod13<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.nfv,data=data.frame1)
  mod14<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.lpv,data=data.frame1)
  mod15<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
               init.reason.cat+strat(site)+r2.idv,data=data.frame1)
  
  lhr2.3tc<-summary(mod2)[c(15),c(4,5)]
  lhr2.ftc<-summary(mod3)[c(15),c(4,5)]
  lhr2.efv<-summary(mod4)[c(15),c(4,5)]
  lhr2.nvp<-summary(mod5)[c(15),c(4,5)]
  lhr2.abc<-summary(mod6)[c(15),c(4,5)]
  lhr2.azt<-summary(mod7)[c(15),c(4,5)]
  lhr2.d4t<-summary(mod8)[c(15),c(4,5)]
  lhr2.ddi<-summary(mod9)[c(15),c(4,5)]
  lhr2.tdf<-summary(mod10)[c(15),c(4,5)]
  lhr2.atv<-summary(mod11)[c(15),c(4,5)]
  lhr2.sqv<-summary(mod12)[c(15),c(4,5)]  
  lhr2.nfv<-summary(mod13)[c(15),c(4,5)]
  lhr2.lpv<-summary(mod14)[c(15),c(4,5)]
  lhr2.idv<-summary(mod15)[c(15),c(4,5)]
  
  lhr2.est[,i]<-rbind(lhr2.3tc[1],lhr2.ftc[1],lhr2.efv[1],lhr2.nvp[1],lhr2.abc[1],lhr2.azt[1],
                      lhr2.d4t[1],lhr2.ddi[1],lhr2.tdf[1],lhr2.atv[1],lhr2.sqv[1],lhr2.nfv[1],lhr2.lpv[1],lhr2.idv[1])
  lhr2.ses[,i]<-rbind(lhr2.3tc[2],lhr2.ftc[2],lhr2.efv[2],lhr2.nvp[2],lhr2.abc[2],lhr2.azt[2],
                      lhr2.d4t[2],lhr2.ddi[2],lhr2.tdf[2],lhr2.atv[2],lhr2.sqv[2],lhr2.nfv[2],lhr2.lpv[2],lhr2.idv[2])
  
  mod.nnrti<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.efv,data=data.frame1, subset=(r2.efv==1|r2.nvp==1)&!(r2.efv==1&r2.nvp==1))
  mod.nrti<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                  init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi)&(r2.abc+r2.azt+r2.d4t+r2.tdf+r2.ddi==1))
  mod.nrti2<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                   init.reason.cat+strat(site)+r2.abc+r2.d4t+r2.tdf+r2.ddi,data=data.frame1, 
                 subset=(r2.abc==1|r2.azt==1|r2.d4t==1|r2.tdf==1|r2.ddi))
  mod.bpi<-cph(Surv(exp(log.time.fail.),fail)~male+rcs(age2,4)+aids.enrollment+rcs(sqrt.cd41.,4)+rcs(sqrt.cd42.,4)+year2+rcs(log(time.since.haart.y),3)+
                 init.reason.cat+strat(site)+r2.atv+r2.idv+r2.sqv,data=data.frame1, 
               subset=(r2.atv==1|r2.nfv==1|r2.idv==1|r2.lpv==1|r2.sqv==1)&second.class=="BOOSTED PI"&(r2.atv+r2.nfv+r2.idv+r2.lpv+r2.sqv==1))
  ####  NFV removed because of singular matrix
  
  lhr2A.efv<-summary(mod.nnrti)[c(15),c(4,5)]
  lhr2A.abc<-summary(mod.nrti)[c(15),c(4,5)]
  lhr2A.d4t<-summary(mod.nrti)[c(17),c(4,5)]
  lhr2A.ddi<-summary(mod.nrti)[c(21),c(4,5)]
  lhr2A.tdf<-summary(mod.nrti)[c(19),c(4,5)]
  lhr2B.abc<-summary(mod.nrti2)[c(15),c(4,5)]
  lhr2B.d4t<-summary(mod.nrti2)[c(17),c(4,5)]
  lhr2B.ddi<-summary(mod.nrti2)[c(21),c(4,5)]
  lhr2B.tdf<-summary(mod.nrti2)[c(19),c(4,5)]
  lhr2A.atv<-summary(mod.bpi)[c(15),c(4,5)]
  lhr2A.idv<-summary(mod.bpi)[c(17),c(4,5)]
  lhr2A.sqv<-summary(mod.bpi)[c(19),c(4,5)]  
  
  lhr2A.est[,i]<-rbind(lhr2A.efv[1],lhr2A.abc[1],lhr2A.d4t[1],lhr2A.ddi[1],lhr2A.tdf[1],lhr2A.atv[1],lhr2A.sqv[1],lhr2A.idv[1])
  lhr2A.ses[,i]<-rbind(lhr2A.efv[2],lhr2A.abc[2],lhr2A.d4t[2],lhr2A.ddi[2],lhr2A.tdf[2],lhr2A.atv[2],lhr2A.sqv[2],lhr2A.idv[2])
  
  lhr2B.est[,i]<-rbind(lhr2B.abc[1],lhr2B.d4t[1],lhr2B.ddi[1],lhr2B.tdf[1])
  lhr2B.ses[,i]<-rbind(lhr2B.abc[2],lhr2B.d4t[2],lhr2B.ddi[2],lhr2B.tdf[2])
  
  
  
  
}

log.hr.reg<-apply(lhr2.est,1,mean)
ses.log.hr.reg<-sqrt(apply(lhr2.ses^2,1,mean)+(M+1)*apply(lhr2.est,1,var)/M)
hr.reg<-exp(log.hr.reg)
hr.reg.lower<-exp(log.hr.reg-1.96*ses.log.hr.reg)
hr.reg.upper<-exp(log.hr.reg+1.96*ses.log.hr.reg)
p.val.reg<-2*pnorm(-abs(log.hr.reg/ses.log.hr.reg))

hr.fail.reg<-cbind(hr.reg,hr.reg.lower,hr.reg.upper,p.val.reg)
names.hr.fail.reg<-c("3tc","ftc","efv","nvp","abc","azt","d4t","ddi","tdf","atv","sqv","nfv","lpv","idv")

log.hr.regA<-apply(lhr2A.est,1,mean)
ses.log.hr.regA<-sqrt(apply(lhr2A.ses^2,1,mean)+(M+1)*apply(lhr2A.est,1,var)/M)
hr.regA<-exp(log.hr.regA)
hr.reg.lowerA<-exp(log.hr.regA-1.96*ses.log.hr.regA)
hr.reg.upperA<-exp(log.hr.regA+1.96*ses.log.hr.regA)
p.val.regA<-2*pnorm(-abs(log.hr.regA/ses.log.hr.regA))

hr.fail.regA<-cbind(hr.regA,hr.reg.lowerA,hr.reg.upperA,p.val.regA)
names.hr.fail.regA<-c("efv","abc","d4t","ddi","tdf","atv","sqv","idv")

log.hr.regB<-apply(lhr2B.est,1,mean)
ses.log.hr.regB<-sqrt(apply(lhr2B.ses^2,1,mean)+(M+1)*apply(lhr2B.est,1,var)/M)
hr.regB<-exp(log.hr.regB)
hr.reg.lowerB<-exp(log.hr.regB-1.96*ses.log.hr.regB)
hr.reg.upperB<-exp(log.hr.regB+1.96*ses.log.hr.regB)
p.val.regB<-2*pnorm(-abs(log.hr.regB/ses.log.hr.regB))

hr.fail.regB<-cbind(hr.regB,hr.reg.lowerB,hr.reg.upperB,p.val.regB)
names.hr.fail.regB<-c("abc","d4t","ddi","tdf")

save(hr.fail.reg,names.hr.fail.reg,hr.fail.regA,names.hr.fail.regA,hr.fail.regB,names.hr.fail.regB,file="hr-fail-reg-adj.Rda")


